import{C as $e,D as bn,E as In,F as An,S as ae,i as oe,s as le,G as ue,H as B,k as ye,l as Le,m as ce,h as E,I as re,b as M,J as ne,K as de,L as fe,M as me,N as Ae,O as Be,g as y,d as L,P as Ve,Q as K,R as Ee,o as Bt,T as Se,U as Pn,w as he,x as Pe,y as w,e as Ie,z as V,A as N,V as be,f as mt,B as H,W as De,X as pe,Y as At,v as ht,Z as Pt,_ as Un,a as ve,c as Ce,n as Me,$ as Ut,a0 as wt,a1 as Qt,a2 as wn,a3 as Nn,q as We,r as Xe,a4 as Hn,a5 as jn}from"../chunks/index.72b3cb36.js";import{r as Gn}from"../chunks/index.a6ab0d54.js";import{_ as et,a as Ne,b as yt,c as ze,f as pt,S as ft,u as Vt,d as Yt,e as zn,M as En,g as st,h as He,p as Vn,R as xt}from"../chunks/Ripple.6b4d2b6a.js";/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Wn=function(){function i(e){e===void 0&&(e={}),this.adapter=e}return Object.defineProperty(i,"cssClasses",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"strings",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"numbers",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"defaultAdapter",{get:function(){return{}},enumerable:!1,configurable:!0}),i.prototype.init=function(){},i.prototype.destroy=function(){},i}();/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var ot={FIXED_CLASS:"mdc-top-app-bar--fixed",FIXED_SCROLLED_CLASS:"mdc-top-app-bar--fixed-scrolled",SHORT_CLASS:"mdc-top-app-bar--short",SHORT_COLLAPSED_CLASS:"mdc-top-app-bar--short-collapsed",SHORT_HAS_ACTION_ITEM_CLASS:"mdc-top-app-bar--short-has-action-item"},Mt={DEBOUNCE_THROTTLE_RESIZE_TIME_MS:100,MAX_TOP_APP_BAR_HEIGHT:128},Xn={ACTION_ITEM_SELECTOR:".mdc-top-app-bar__action-item",NAVIGATION_EVENT:"MDCTopAppBar:nav",NAVIGATION_ICON_SELECTOR:".mdc-top-app-bar__navigation-icon",ROOT_SELECTOR:".mdc-top-app-bar",TITLE_SELECTOR:".mdc-top-app-bar__title"};/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Wt=function(i){et(e,i);function e(t){return i.call(this,Ne(Ne({},e.defaultAdapter),t))||this}return Object.defineProperty(e,"strings",{get:function(){return Xn},enumerable:!1,configurable:!0}),Object.defineProperty(e,"cssClasses",{get:function(){return ot},enumerable:!1,configurable:!0}),Object.defineProperty(e,"numbers",{get:function(){return Mt},enumerable:!1,configurable:!0}),Object.defineProperty(e,"defaultAdapter",{get:function(){return{addClass:function(){},removeClass:function(){},hasClass:function(){return!1},setStyle:function(){},getTopAppBarHeight:function(){return 0},notifyNavigationIconClicked:function(){},getViewportScrollY:function(){return 0},getTotalActionItems:function(){return 0}}},enumerable:!1,configurable:!0}),e.prototype.handleTargetScroll=function(){},e.prototype.handleWindowResize=function(){},e.prototype.handleNavigationClick=function(){this.adapter.notifyNavigationIconClicked()},e}(Wn);/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Lt=0,Sn=function(i){et(e,i);function e(t){var n=i.call(this,t)||this;return n.wasDocked=!0,n.isDockedShowing=!0,n.currentAppBarOffsetTop=0,n.isCurrentlyBeingResized=!1,n.resizeThrottleId=Lt,n.resizeDebounceId=Lt,n.lastScrollPosition=n.adapter.getViewportScrollY(),n.topAppBarHeight=n.adapter.getTopAppBarHeight(),n}return e.prototype.destroy=function(){i.prototype.destroy.call(this),this.adapter.setStyle("top","")},e.prototype.handleTargetScroll=function(){var t=Math.max(this.adapter.getViewportScrollY(),0),n=t-this.lastScrollPosition;this.lastScrollPosition=t,this.isCurrentlyBeingResized||(this.currentAppBarOffsetTop-=n,this.currentAppBarOffsetTop>0?this.currentAppBarOffsetTop=0:Math.abs(this.currentAppBarOffsetTop)>this.topAppBarHeight&&(this.currentAppBarOffsetTop=-this.topAppBarHeight),this.moveTopAppBar())},e.prototype.handleWindowResize=function(){var t=this;this.resizeThrottleId||(this.resizeThrottleId=setTimeout(function(){t.resizeThrottleId=Lt,t.throttledResizeHandler()},Mt.DEBOUNCE_THROTTLE_RESIZE_TIME_MS)),this.isCurrentlyBeingResized=!0,this.resizeDebounceId&&clearTimeout(this.resizeDebounceId),this.resizeDebounceId=setTimeout(function(){t.handleTargetScroll(),t.isCurrentlyBeingResized=!1,t.resizeDebounceId=Lt},Mt.DEBOUNCE_THROTTLE_RESIZE_TIME_MS)},e.prototype.checkForUpdate=function(){var t=-this.topAppBarHeight,n=this.currentAppBarOffsetTop<0,a=this.currentAppBarOffsetTop>t,r=n&&a;if(r)this.wasDocked=!1;else if(this.wasDocked){if(this.isDockedShowing!==a)return this.isDockedShowing=a,!0}else return this.wasDocked=!0,!0;return r},e.prototype.moveTopAppBar=function(){if(this.checkForUpdate()){var t=this.currentAppBarOffsetTop;Math.abs(t)>=this.topAppBarHeight&&(t=-Mt.MAX_TOP_APP_BAR_HEIGHT),this.adapter.setStyle("top",t+"px")}},e.prototype.throttledResizeHandler=function(){var t=this.adapter.getTopAppBarHeight();this.topAppBarHeight!==t&&(this.wasDocked=!1,this.currentAppBarOffsetTop-=this.topAppBarHeight-t,this.topAppBarHeight=t),this.handleTargetScroll()},e}(Wt);/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Kn=function(i){et(e,i);function e(){var t=i!==null&&i.apply(this,arguments)||this;return t.wasScrolled=!1,t}return e.prototype.handleTargetScroll=function(){var t=this.adapter.getViewportScrollY();t<=0?this.wasScrolled&&(this.adapter.removeClass(ot.FIXED_SCROLLED_CLASS),this.wasScrolled=!1):this.wasScrolled||(this.adapter.addClass(ot.FIXED_SCROLLED_CLASS),this.wasScrolled=!0)},e}(Sn);/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var qn=function(i){et(e,i);function e(t){var n=i.call(this,t)||this;return n.collapsed=!1,n.isAlwaysCollapsed=!1,n}return Object.defineProperty(e.prototype,"isCollapsed",{get:function(){return this.collapsed},enumerable:!1,configurable:!0}),e.prototype.init=function(){i.prototype.init.call(this),this.adapter.getTotalActionItems()>0&&this.adapter.addClass(ot.SHORT_HAS_ACTION_ITEM_CLASS),this.setAlwaysCollapsed(this.adapter.hasClass(ot.SHORT_COLLAPSED_CLASS))},e.prototype.setAlwaysCollapsed=function(t){this.isAlwaysCollapsed=!!t,this.isAlwaysCollapsed?this.collapse():this.maybeCollapseBar()},e.prototype.getAlwaysCollapsed=function(){return this.isAlwaysCollapsed},e.prototype.handleTargetScroll=function(){this.maybeCollapseBar()},e.prototype.maybeCollapseBar=function(){if(!this.isAlwaysCollapsed){var t=this.adapter.getViewportScrollY();t<=0?this.collapsed&&this.uncollapse():this.collapsed||this.collapse()}},e.prototype.uncollapse=function(){this.adapter.removeClass(ot.SHORT_COLLAPSED_CLASS),this.collapsed=!1},e.prototype.collapse=function(){this.adapter.addClass(ot.SHORT_COLLAPSED_CLASS),this.collapsed=!0},e}(Wt);function rt(i){return Object.entries(i).filter(([e,t])=>e!==""&&t).map(([e])=>e).join(" ")}function Zn(i,e,t,n={bubbles:!0},a=!1){if(typeof Event<"u"&&i){const r=new CustomEvent(e,Object.assign(Object.assign({},n),{detail:t}));if(i==null||i.dispatchEvent(r),a&&e.startsWith("SMUI")){const l=new CustomEvent(e.replace(/^SMUI/g,()=>"MDC"),Object.assign(Object.assign({},n),{detail:t}));i==null||i.dispatchEvent(l),l.defaultPrevented&&r.preventDefault()}return r}}const $t=/^[a-z]+(?::(?:preventDefault|stopPropagation|passive|nonpassive|capture|once|self))+$/,Jn=/^[^$]+(?:\$(?:preventDefault|stopPropagation|passive|nonpassive|capture|once|self))+$/;function lt(i){let e,t=[];i.$on=(a,r)=>{let l=a,s=()=>{};return e?s=e(l,r):t.push([l,r]),l.match($t)&&console&&console.warn('Event modifiers in SMUI now use "$" instead of ":", so that all events can be bound with modifiers. Please update your event binding: ',l),()=>{s()}};function n(a){bn(i,a)}return a=>{const r=[],l={};e=(s,o)=>{let c=s,u=o,d=!1;const f=c.match($t),h=c.match(Jn),g=f||h;if(c.match(/^SMUI:\w+:/)){const C=c.split(":");let p="";for(let b=0;b<C.length;b++)p+=b===C.length-1?":"+C[b]:C[b].split("-").map(R=>R.slice(0,1).toUpperCase()+R.slice(1)).join("");console.warn(`The event ${c.split("$")[0]} has been renamed to ${p.split("$")[0]}.`),c=p}if(g){const C=c.split(f?":":"$");c=C[0];const p=Object.fromEntries(C.slice(1).map(b=>[b,!0]));p.passive&&(d=d||{},d.passive=!0),p.nonpassive&&(d=d||{},d.passive=!1),p.capture&&(d=d||{},d.capture=!0),p.once&&(d=d||{},d.once=!0),p.preventDefault&&(u=In(u)),p.stopPropagation&&(u=An(u))}const I=$e(a,c,u,d),v=()=>{I();const C=r.indexOf(v);C>-1&&r.splice(C,1)};return r.push(v),c in l||(l[c]=$e(a,c,n)),v};for(let s=0;s<t.length;s++)e(t[s][0],t[s][1]);return{destroy:()=>{for(let s=0;s<r.length;s++)r[s]();for(let s of Object.entries(l))s[1]()}}}}function Et(i,e){let t=[];if(e)for(let n=0;n<e.length;n++){const a=e[n],r=Array.isArray(a)?a[0]:a;Array.isArray(a)&&a.length>1?t.push(r(i,a[1])):t.push(r(i))}return{update(n){if((n&&n.length||0)!=t.length)throw new Error("You must not change the length of an actions array.");if(n)for(let a=0;a<n.length;a++){const r=t[a];if(r&&r.update){const l=n[a];Array.isArray(l)&&l.length>1?r.update(l[1]):r.update()}}},destroy(){for(let n=0;n<t.length;n++){const a=t[n];a&&a.destroy&&a.destroy()}}}}const{window:en}=Pn;function Qn(i){let e,t,n,a,r,l,s;const o=i[22].default,c=ue(o,i,i[21],null);let u=[{class:t=rt({[i[2]]:!0,"mdc-top-app-bar":!0,"mdc-top-app-bar--short":i[4]==="short","mdc-top-app-bar--short-collapsed":i[0],"mdc-top-app-bar--fixed":i[4]==="fixed","smui-top-app-bar--static":i[4]==="static","smui-top-app-bar--color-secondary":i[5]==="secondary","mdc-top-app-bar--prominent":i[6],"mdc-top-app-bar--dense":i[7],...i[11]})},{style:n=Object.entries(i[12]).map(tn).concat([i[3]]).join(" ")},i[15]],d={};for(let f=0;f<u.length;f+=1)d=B(d,u[f]);return{c(){e=ye("header"),c&&c.c(),this.h()},l(f){e=Le(f,"HEADER",{class:!0,style:!0});var h=ce(e);c&&c.l(h),h.forEach(E),this.h()},h(){re(e,d)},m(f,h){M(f,e,h),c&&c.m(e,null),i[25](e),r=!0,l||(s=[$e(en,"resize",i[23]),$e(en,"scroll",i[24]),ne(a=Et.call(null,e,i[1])),ne(i[13].call(null,e)),$e(e,"SMUITopAppBarIconButton:nav",i[26])],l=!0)},p(f,h){c&&c.p&&(!r||h[0]&2097152)&&de(c,o,f,f[21],r?me(o,f[21],h,null):fe(f[21]),null),re(e,d=Ae(u,[(!r||h[0]&2293&&t!==(t=rt({[f[2]]:!0,"mdc-top-app-bar":!0,"mdc-top-app-bar--short":f[4]==="short","mdc-top-app-bar--short-collapsed":f[0],"mdc-top-app-bar--fixed":f[4]==="fixed","smui-top-app-bar--static":f[4]==="static","smui-top-app-bar--color-secondary":f[5]==="secondary","mdc-top-app-bar--prominent":f[6],"mdc-top-app-bar--dense":f[7],...f[11]})))&&{class:t},(!r||h[0]&4104&&n!==(n=Object.entries(f[12]).map(tn).concat([f[3]]).join(" ")))&&{style:n},h[0]&32768&&f[15]])),a&&Be(a.update)&&h[0]&2&&a.update.call(null,f[1])},i(f){r||(y(c,f),r=!0)},o(f){L(c,f),r=!1},d(f){f&&E(e),c&&c.d(f),i[25](null),l=!1,Ve(s)}}}const tn=([i,e])=>`${i}: ${e};`;function Yn(i,e,t){const n=["use","class","style","variant","color","collapsed","prominent","dense","scrollTarget","getPropStore","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e;const s=lt(Ee());let o=()=>{};function c(F){return F===o}let{use:u=[]}=e,{class:d=""}=e,{style:f=""}=e,{variant:h="standard"}=e,{color:g="primary"}=e,{collapsed:I=o}=e;const v=!c(I)&&!!I;c(I)&&(I=!1);let{prominent:C=!1}=e,{dense:p=!1}=e,{scrollTarget:b=void 0}=e,R,S,k={},j={},J,$=Gn({variant:h,prominent:C,dense:p},F=>{t(18,J=F)}),q,X=h;Bt(()=>(t(9,S=Z()),S.init(),()=>{S.destroy()}));function Z(){const F={static:Wt,short:qn,fixed:Kn}[h]||Sn;return new F({hasClass:Q,addClass:T,removeClass:z,setStyle:P,getTopAppBarHeight:()=>R.clientHeight,notifyNavigationIconClicked:()=>Zn(R,"SMUITopAppBar:nav",void 0,void 0,!0),getViewportScrollY:()=>b==null?window.pageYOffset:b.scrollTop,getTotalActionItems:()=>R.querySelectorAll(".mdc-top-app-bar__action-item").length})}function Q(F){return F in k?k[F]:Ke().classList.contains(F)}function T(F){k[F]||t(11,k[F]=!0,k)}function z(F){(!(F in k)||k[F])&&t(11,k[F]=!1,k)}function P(F,Ue){j[F]!=Ue&&(Ue===""||Ue==null?(delete j[F],t(12,j),t(20,X),t(4,h),t(9,S)):t(12,j[F]=Ue,j))}function Y(){S&&(S.handleTargetScroll(),h==="short"&&t(0,I="isCollapsed"in S&&S.isCollapsed))}function ie(){return $}function Ke(){return R}const je=()=>h!=="short"&&h!=="fixed"&&S&&S.handleWindowResize(),qe=()=>b==null&&Y();function Ze(F){he[F?"unshift":"push"](()=>{R=F,t(10,R)})}const Je=()=>S&&S.handleNavigationClick();return i.$$set=F=>{e=B(B({},e),Se(F)),t(15,a=K(e,n)),"use"in F&&t(1,u=F.use),"class"in F&&t(2,d=F.class),"style"in F&&t(3,f=F.style),"variant"in F&&t(4,h=F.variant),"color"in F&&t(5,g=F.color),"collapsed"in F&&t(0,I=F.collapsed),"prominent"in F&&t(6,C=F.prominent),"dense"in F&&t(7,p=F.dense),"scrollTarget"in F&&t(8,b=F.scrollTarget),"$$scope"in F&&t(21,l=F.$$scope)},i.$$.update=()=>{i.$$.dirty[0]&262352&&J&&J({variant:h,prominent:C,dense:p}),i.$$.dirty[0]&1049104&&X!==h&&S&&(t(20,X=h),S.destroy(),t(11,k={}),t(12,j={}),t(9,S=Z()),S.init()),i.$$.dirty[0]&528&&S&&h==="short"&&"setAlwaysCollapsed"in S&&S.setAlwaysCollapsed(v),i.$$.dirty[0]&524544&&q!==b&&(q&&q.removeEventListener("scroll",Y),b&&b.addEventListener("scroll",Y),t(19,q=b))},[I,u,d,f,h,g,C,p,b,S,R,k,j,s,Y,a,ie,Ke,J,q,X,l,r,je,qe,Ze,Je]}class xn extends ae{constructor(e){super(),oe(this,e,Yn,Qn,le,{use:1,class:2,style:3,variant:4,color:5,collapsed:0,prominent:6,dense:7,scrollTarget:8,getPropStore:16,getElement:17},null,[-1,-1])}get getPropStore(){return this.$$.ctx[16]}get getElement(){return this.$$.ctx[17]}}function $n(i){let e,t,n,a,r;const l=i[6].default,s=ue(l,i,i[5],null);let o=[i[3]],c={};for(let u=0;u<o.length;u+=1)c=B(c,o[u]);return{c(){e=ye("div"),s&&s.c(),this.h()},l(u){e=Le(u,"DIV",{});var d=ce(e);s&&s.l(d),d.forEach(E),this.h()},h(){re(e,c)},m(u,d){M(u,e,d),s&&s.m(e,null),i[7](e),n=!0,a||(r=[ne(t=Et.call(null,e,i[0])),ne(i[2].call(null,e))],a=!0)},p(u,[d]){s&&s.p&&(!n||d&32)&&de(s,l,u,u[5],n?me(l,u[5],d,null):fe(u[5]),null),re(e,c=Ae(o,[d&8&&u[3]])),t&&Be(t.update)&&d&1&&t.update.call(null,u[0])},i(u){n||(y(s,u),n=!0)},o(u){L(s,u),n=!1},d(u){u&&E(e),s&&s.d(u),i[7](null),a=!1,Ve(r)}}}function ei(i,e,t){const n=["use","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e,{use:s=[]}=e;const o=lt(Ee());let c;function u(){return c}function d(f){he[f?"unshift":"push"](()=>{c=f,t(1,c)})}return i.$$set=f=>{e=B(B({},e),Se(f)),t(3,a=K(e,n)),"use"in f&&t(0,s=f.use),"$$scope"in f&&t(5,l=f.$$scope)},[s,c,o,a,u,l,r,d]}let vn=class extends ae{constructor(e){super(),oe(this,e,ei,$n,le,{use:0,getElement:4})}get getElement(){return this.$$.ctx[4]}};function ti(i){let e;const t=i[10].default,n=ue(t,i,i[12],null);return{c(){n&&n.c()},l(a){n&&n.l(a)},m(a,r){n&&n.m(a,r),e=!0},p(a,r){n&&n.p&&(!e||r&4096)&&de(n,t,a,a[12],e?me(t,a[12],r,null):fe(a[12]),null)},i(a){e||(y(n,a),e=!0)},o(a){L(n,a),e=!1},d(a){n&&n.d(a)}}}function ni(i){let e,t,n;const a=[{use:[i[7],...i[0]]},{class:rt({[i[1]]:!0,[i[5]]:!0,...i[4]})},i[6],i[8]];var r=i[2];function l(s){let o={$$slots:{default:[ti]},$$scope:{ctx:s}};for(let c=0;c<a.length;c+=1)o=B(o,a[c]);return{props:o}}return r&&(e=Pe(r,l(i)),i[11](e)),{c(){e&&w(e.$$.fragment),t=Ie()},l(s){e&&V(e.$$.fragment,s),t=Ie()},m(s,o){e&&N(e,s,o),M(s,t,o),n=!0},p(s,[o]){const c=o&499?Ae(a,[o&129&&{use:[s[7],...s[0]]},o&50&&{class:rt({[s[1]]:!0,[s[5]]:!0,...s[4]})},o&64&&be(s[6]),o&256&&be(s[8])]):{};if(o&4096&&(c.$$scope={dirty:o,ctx:s}),r!==(r=s[2])){if(e){ht();const u=e;L(u.$$.fragment,1,0,()=>{H(u,1)}),mt()}r?(e=Pe(r,l(s)),s[11](e),w(e.$$.fragment),y(e.$$.fragment,1),N(e,t.parentNode,t)):e=null}else r&&e.$set(c)},i(s){n||(e&&y(e.$$.fragment,s),n=!0)},o(s){e&&L(e.$$.fragment,s),n=!1},d(s){i[11](null),s&&E(t),e&&H(e,s)}}}const it={component:vn,class:"",classMap:{},contexts:{},props:{}};function ii(i,e,t){const n=["use","class","component","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e,{use:s=[]}=e,{class:o=""}=e,c;const u=it.class,d={},f=[],h=it.contexts,g=it.props;let{component:I=it.component}=e;Object.entries(it.classMap).forEach(([b,R])=>{const S=De(R);S&&"subscribe"in S&&f.push(S.subscribe(k=>{t(4,d[b]=k,d)}))});const v=lt(Ee());for(let b in h)h.hasOwnProperty(b)&&pe(b,h[b]);At(()=>{for(const b of f)b()});function C(){return c.getElement()}function p(b){he[b?"unshift":"push"](()=>{c=b,t(3,c)})}return i.$$set=b=>{e=B(B({},e),Se(b)),t(8,a=K(e,n)),"use"in b&&t(0,s=b.use),"class"in b&&t(1,o=b.class),"component"in b&&t(2,I=b.component),"$$scope"in b&&t(12,l=b.$$scope)},[s,o,I,c,d,u,g,v,a,C,r,p,l]}class si extends ae{constructor(e){super(),oe(this,e,ii,ni,le,{use:0,class:1,component:2,getElement:9})}get getElement(){return this.$$.ctx[9]}}const nn=Object.assign({},it);function Cn(i){return new Proxy(si,{construct:function(e,t){return Object.assign(it,nn,i),new e(...t)},get:function(e,t){return Object.assign(it,nn,i),e[t]}})}function ri(i){let e,t,n,a,r;const l=i[6].default,s=ue(l,i,i[5],null);let o=[i[3]],c={};for(let u=0;u<o.length;u+=1)c=B(c,o[u]);return{c(){e=ye("main"),s&&s.c(),this.h()},l(u){e=Le(u,"MAIN",{});var d=ce(e);s&&s.l(d),d.forEach(E),this.h()},h(){re(e,c)},m(u,d){M(u,e,d),s&&s.m(e,null),i[7](e),n=!0,a||(r=[ne(t=Et.call(null,e,i[0])),ne(i[2].call(null,e))],a=!0)},p(u,[d]){s&&s.p&&(!n||d&32)&&de(s,l,u,u[5],n?me(l,u[5],d,null):fe(u[5]),null),re(e,c=Ae(o,[d&8&&u[3]])),t&&Be(t.update)&&d&1&&t.update.call(null,u[0])},i(u){n||(y(s,u),n=!0)},o(u){L(s,u),n=!1},d(u){u&&E(e),s&&s.d(u),i[7](null),a=!1,Ve(r)}}}function ai(i,e,t){const n=["use","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e,{use:s=[]}=e;const o=lt(Ee());let c;function u(){return c}function d(f){he[f?"unshift":"push"](()=>{c=f,t(1,c)})}return i.$$set=f=>{e=B(B({},e),Se(f)),t(3,a=K(e,n)),"use"in f&&t(0,s=f.use),"$$scope"in f&&t(5,l=f.$$scope)},[s,c,o,a,u,l,r,d]}let oi=class extends ae{constructor(e){super(),oe(this,e,ai,ri,le,{use:0,getElement:4})}get getElement(){return this.$$.ctx[4]}};function li(i){let e,t,n,a,r;const l=i[6].default,s=ue(l,i,i[5],null);let o=[i[3]],c={};for(let u=0;u<o.length;u+=1)c=B(c,o[u]);return{c(){e=ye("span"),s&&s.c(),this.h()},l(u){e=Le(u,"SPAN",{});var d=ce(e);s&&s.l(d),d.forEach(E),this.h()},h(){re(e,c)},m(u,d){M(u,e,d),s&&s.m(e,null),i[7](e),n=!0,a||(r=[ne(t=Et.call(null,e,i[0])),ne(i[2].call(null,e))],a=!0)},p(u,[d]){s&&s.p&&(!n||d&32)&&de(s,l,u,u[5],n?me(l,u[5],d,null):fe(u[5]),null),re(e,c=Ae(o,[d&8&&u[3]])),t&&Be(t.update)&&d&1&&t.update.call(null,u[0])},i(u){n||(y(s,u),n=!0)},o(u){L(s,u),n=!1},d(u){u&&E(e),s&&s.d(u),i[7](null),a=!1,Ve(r)}}}function ui(i,e,t){const n=["use","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e,{use:s=[]}=e;const o=lt(Ee());let c;function u(){return c}function d(f){he[f?"unshift":"push"](()=>{c=f,t(1,c)})}return i.$$set=f=>{e=B(B({},e),Se(f)),t(3,a=K(e,n)),"use"in f&&t(0,s=f.use),"$$scope"in f&&t(5,l=f.$$scope)},[s,c,o,a,u,l,r,d]}let ci=class extends ae{constructor(e){super(),oe(this,e,ui,li,le,{use:0,getElement:4})}get getElement(){return this.$$.ctx[4]}};const di=vn,fi=oi,mi=ci,hi=Cn({class:"mdc-top-app-bar__row",component:di});function pi(i){let e,t,n,a,r,l;const s=i[9].default,o=ue(s,i,i[8],null);let c=[{class:t=rt({[i[1]]:!0,"mdc-top-app-bar__section":!0,"mdc-top-app-bar__section--align-start":i[2]==="start","mdc-top-app-bar__section--align-end":i[2]==="end"})},i[3]?{role:"toolbar"}:{},i[6]],u={};for(let d=0;d<c.length;d+=1)u=B(u,c[d]);return{c(){e=ye("section"),o&&o.c(),this.h()},l(d){e=Le(d,"SECTION",{class:!0});var f=ce(e);o&&o.l(f),f.forEach(E),this.h()},h(){re(e,u)},m(d,f){M(d,e,f),o&&o.m(e,null),i[10](e),a=!0,r||(l=[ne(n=Et.call(null,e,i[0])),ne(i[5].call(null,e))],r=!0)},p(d,[f]){o&&o.p&&(!a||f&256)&&de(o,s,d,d[8],a?me(s,d[8],f,null):fe(d[8]),null),re(e,u=Ae(c,[(!a||f&6&&t!==(t=rt({[d[1]]:!0,"mdc-top-app-bar__section":!0,"mdc-top-app-bar__section--align-start":d[2]==="start","mdc-top-app-bar__section--align-end":d[2]==="end"})))&&{class:t},f&8&&(d[3]?{role:"toolbar"}:{}),f&64&&d[6]])),n&&Be(n.update)&&f&1&&n.update.call(null,d[0])},i(d){a||(y(o,d),a=!0)},o(d){L(o,d),a=!1},d(d){d&&E(e),o&&o.d(d),i[10](null),r=!1,Ve(l)}}}function gi(i,e,t){const n=["use","class","align","toolbar","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e;const s=lt(Ee());let{use:o=[]}=e,{class:c=""}=e,{align:u="start"}=e,{toolbar:d=!1}=e,f;pe("SMUI:icon-button:context",d?"top-app-bar:action":"top-app-bar:navigation"),pe("SMUI:button:context",d?"top-app-bar:action":"top-app-bar:navigation");function h(){return f}function g(I){he[I?"unshift":"push"](()=>{f=I,t(4,f)})}return i.$$set=I=>{e=B(B({},e),Se(I)),t(6,a=K(e,n)),"use"in I&&t(0,o=I.use),"class"in I&&t(1,c=I.class),"align"in I&&t(2,u=I.align),"toolbar"in I&&t(3,d=I.toolbar),"$$scope"in I&&t(8,l=I.$$scope)},[o,c,u,d,f,s,a,h,l,r,g]}let _i=class extends ae{constructor(e){super(),oe(this,e,gi,pi,le,{use:0,class:1,align:2,toolbar:3,getElement:7})}get getElement(){return this.$$.ctx[7]}};const bi=Cn({class:"mdc-top-app-bar__title",component:mi});function Ii(i){let e;const t=i[11].default,n=ue(t,i,i[13],null);return{c(){n&&n.c()},l(a){n&&n.l(a)},m(a,r){n&&n.m(a,r),e=!0},p(a,r){n&&n.p&&(!e||r&8192)&&de(n,t,a,a[13],e?me(t,a[13],r,null):fe(a[13]),null)},i(a){e||(y(n,a),e=!0)},o(a){L(n,a),e=!1},d(a){n&&n.d(a)}}}function Ai(i){let e,t,n;const a=[{use:[i[6],...i[0]]},{class:rt({[i[1]]:!0,[i[5]]:!0})},i[7]];var r=i[2];function l(s){let o={$$slots:{default:[Ii]},$$scope:{ctx:s}};for(let c=0;c<a.length;c+=1)o=B(o,a[c]);return{props:o}}return r&&(e=Pe(r,l(i)),i[12](e)),{c(){e&&w(e.$$.fragment),t=Ie()},l(s){e&&V(e.$$.fragment,s),t=Ie()},m(s,o){e&&N(e,s,o),M(s,t,o),n=!0},p(s,[o]){const c=o&227?Ae(a,[o&65&&{use:[s[6],...s[0]]},o&34&&{class:rt({[s[1]]:!0,[s[5]]:!0})},o&128&&be(s[7])]):{};if(o&8192&&(c.$$scope={dirty:o,ctx:s}),r!==(r=s[2])){if(e){ht();const u=e;L(u.$$.fragment,1,0,()=>{H(u,1)}),mt()}r?(e=Pe(r,l(s)),s[12](e),w(e.$$.fragment),y(e.$$.fragment,1),N(e,t.parentNode,t)):e=null}else r&&e.$set(c)},i(s){n||(e&&y(e.$$.fragment,s),n=!0)},o(s){e&&L(e.$$.fragment,s),n=!1},d(s){i[12](null),s&&E(t),e&&H(e,s)}}}function Ei(i,e,t){let n,a;const r=["use","class","topAppBar","component","getElement"];let l=K(e,r),s,o=Pt,c=()=>(o(),o=Un(n,R=>t(10,s=R)),n);i.$$.on_destroy.push(()=>o());let{$$slots:u={},$$scope:d}=e;const f=lt(Ee());let{use:h=[]}=e,{class:g=""}=e,{topAppBar:I}=e,v,{component:C=fi}=e;function p(){return v.getElement()}function b(R){he[R?"unshift":"push"](()=>{v=R,t(4,v)})}return i.$$set=R=>{e=B(B({},e),Se(R)),t(7,l=K(e,r)),"use"in R&&t(0,h=R.use),"class"in R&&t(1,g=R.class),"topAppBar"in R&&t(8,I=R.topAppBar),"component"in R&&t(2,C=R.component),"$$scope"in R&&t(13,d=R.$$scope)},i.$$.update=()=>{i.$$.dirty&256&&c(t(3,n=I&&I.getPropStore())),i.$$.dirty&1032&&t(5,a=(()=>!n||s.variant==="static"?"":s.variant==="short"?"mdc-top-app-bar--short-fixed-adjust":s.prominent&&s.dense?"mdc-top-app-bar--dense-prominent-fixed-adjust":s.prominent?"mdc-top-app-bar--prominent-fixed-adjust":s.dense?"mdc-top-app-bar--dense-fixed-adjust":"mdc-top-app-bar--fixed-adjust")())},[h,g,C,n,v,a,f,l,I,p,s,u,b,d]}let Si=class extends ae{constructor(e){super(),oe(this,e,Ei,Ai,le,{use:0,class:1,topAppBar:8,component:2,getElement:9})}get getElement(){return this.$$.ctx[9]}};const sn=_i,vi=Si;/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Ci=function(){function i(e){e===void 0&&(e={}),this.adapter=e}return Object.defineProperty(i,"cssClasses",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"strings",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"numbers",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"defaultAdapter",{get:function(){return{}},enumerable:!1,configurable:!0}),i.prototype.init=function(){},i.prototype.destroy=function(){},i}();/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Tt={ICON_BUTTON_ON:"mdc-icon-button--on",ROOT:"mdc-icon-button"},Ye={ARIA_LABEL:"aria-label",ARIA_PRESSED:"aria-pressed",DATA_ARIA_LABEL_OFF:"data-aria-label-off",DATA_ARIA_LABEL_ON:"data-aria-label-on",CHANGE_EVENT:"MDCIconButtonToggle:change"};/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var yi=function(i){et(e,i);function e(t){var n=i.call(this,Ne(Ne({},e.defaultAdapter),t))||this;return n.hasToggledAriaLabel=!1,n}return Object.defineProperty(e,"cssClasses",{get:function(){return Tt},enumerable:!1,configurable:!0}),Object.defineProperty(e,"strings",{get:function(){return Ye},enumerable:!1,configurable:!0}),Object.defineProperty(e,"defaultAdapter",{get:function(){return{addClass:function(){},hasClass:function(){return!1},notifyChange:function(){},removeClass:function(){},getAttr:function(){return null},setAttr:function(){}}},enumerable:!1,configurable:!0}),e.prototype.init=function(){var t=this.adapter.getAttr(Ye.DATA_ARIA_LABEL_ON),n=this.adapter.getAttr(Ye.DATA_ARIA_LABEL_OFF);if(t&&n){if(this.adapter.getAttr(Ye.ARIA_PRESSED)!==null)throw new Error("MDCIconButtonToggleFoundation: Button should not set `aria-pressed` if it has a toggled aria label.");this.hasToggledAriaLabel=!0}else this.adapter.setAttr(Ye.ARIA_PRESSED,String(this.isOn()))},e.prototype.handleClick=function(){this.toggle(),this.adapter.notifyChange({isOn:this.isOn()})},e.prototype.isOn=function(){return this.adapter.hasClass(Tt.ICON_BUTTON_ON)},e.prototype.toggle=function(t){if(t===void 0&&(t=!this.isOn()),t?this.adapter.addClass(Tt.ICON_BUTTON_ON):this.adapter.removeClass(Tt.ICON_BUTTON_ON),this.hasToggledAriaLabel){var n=t?this.adapter.getAttr(Ye.DATA_ARIA_LABEL_ON):this.adapter.getAttr(Ye.DATA_ARIA_LABEL_OFF);this.adapter.setAttr(Ye.ARIA_LABEL,n||"")}else this.adapter.setAttr(Ye.ARIA_PRESSED,""+t)},e}(Ci);function rn(i){return Object.entries(i).filter(([e,t])=>e!==""&&t).map(([e])=>e).join(" ")}function an(i,e,t,n={bubbles:!0},a=!1){if(typeof Event<"u"&&i){const r=new CustomEvent(e,Object.assign(Object.assign({},n),{detail:t}));if(i==null||i.dispatchEvent(r),a&&e.startsWith("SMUI")){const l=new CustomEvent(e.replace(/^SMUI/g,()=>"MDC"),Object.assign(Object.assign({},n),{detail:t}));i==null||i.dispatchEvent(l),l.defaultPrevented&&r.preventDefault()}return r}}const on=/^[a-z]+(?::(?:preventDefault|stopPropagation|passive|nonpassive|capture|once|self))+$/,Li=/^[^$]+(?:\$(?:preventDefault|stopPropagation|passive|nonpassive|capture|once|self))+$/;function Xt(i){let e,t=[];i.$on=(a,r)=>{let l=a,s=()=>{};return e?s=e(l,r):t.push([l,r]),l.match(on)&&console&&console.warn('Event modifiers in SMUI now use "$" instead of ":", so that all events can be bound with modifiers. Please update your event binding: ',l),()=>{s()}};function n(a){bn(i,a)}return a=>{const r=[],l={};e=(s,o)=>{let c=s,u=o,d=!1;const f=c.match(on),h=c.match(Li),g=f||h;if(c.match(/^SMUI:\w+:/)){const C=c.split(":");let p="";for(let b=0;b<C.length;b++)p+=b===C.length-1?":"+C[b]:C[b].split("-").map(R=>R.slice(0,1).toUpperCase()+R.slice(1)).join("");console.warn(`The event ${c.split("$")[0]} has been renamed to ${p.split("$")[0]}.`),c=p}if(g){const C=c.split(f?":":"$");c=C[0];const p=Object.fromEntries(C.slice(1).map(b=>[b,!0]));p.passive&&(d=d||{},d.passive=!0),p.nonpassive&&(d=d||{},d.passive=!1),p.capture&&(d=d||{},d.capture=!0),p.once&&(d=d||{},d.once=!0),p.preventDefault&&(u=In(u)),p.stopPropagation&&(u=An(u))}const I=$e(a,c,u,d),v=()=>{I();const C=r.indexOf(v);C>-1&&r.splice(C,1)};return r.push(v),c in l||(l[c]=$e(a,c,n)),v};for(let s=0;s<t.length;s++)e(t[s][0],t[s][1]);return{destroy:()=>{for(let s=0;s<r.length;s++)r[s]();for(let s of Object.entries(l))s[1]()}}}}function yn(i,e){let t=[];if(e)for(let n=0;n<e.length;n++){const a=e[n],r=Array.isArray(a)?a[0]:a;Array.isArray(a)&&a.length>1?t.push(r(i,a[1])):t.push(r(i))}return{update(n){if((n&&n.length||0)!=t.length)throw new Error("You must not change the length of an actions array.");if(n)for(let a=0;a<n.length;a++){const r=t[a];if(r&&r.update){const l=n[a];Array.isArray(l)&&l.length>1?r.update(l[1]):r.update()}}},destroy(){for(let n=0;n<t.length;n++){const a=t[n];a&&a.destroy&&a.destroy()}}}}var Ot;function Ti(i,e){e===void 0&&(e=!1);var t=i.CSS,n=Ot;if(typeof Ot=="boolean"&&!e)return Ot;var a=t&&typeof t.supports=="function";if(!a)return!1;var r=t.supports("--css-vars","yes"),l=t.supports("(--css-vars: yes)")&&t.supports("color","#00000000");return n=r||l,e||(Ot=n),n}function Oi(i,e,t){if(!i)return{x:0,y:0};var n=e.x,a=e.y,r=n+t.left,l=a+t.top,s,o;if(i.type==="touchstart"){var c=i;s=c.changedTouches[0].pageX-r,o=c.changedTouches[0].pageY-l}else{var u=i;s=u.pageX-r,o=u.pageY-l}return{x:s,y:o}}/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Fi=function(){function i(e){e===void 0&&(e={}),this.adapter=e}return Object.defineProperty(i,"cssClasses",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"strings",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"numbers",{get:function(){return{}},enumerable:!1,configurable:!0}),Object.defineProperty(i,"defaultAdapter",{get:function(){return{}},enumerable:!1,configurable:!0}),i.prototype.init=function(){},i.prototype.destroy=function(){},i}();/**
 * @license
 * Copyright 2019 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */function Di(i){return i===void 0&&(i=window),Ri(i)?{passive:!0}:!1}function Ri(i){i===void 0&&(i=window);var e=!1;try{var t={get passive(){return e=!0,!1}},n=function(){};i.document.addEventListener("test",n,t),i.document.removeEventListener("test",n,t)}catch{e=!1}return e}const Mi=Object.freeze(Object.defineProperty({__proto__:null,applyPassive:Di},Symbol.toStringTag,{value:"Module"}));/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */function ki(i,e){if(i.closest)return i.closest(e);for(var t=i;t;){if(Ln(t,e))return t;t=t.parentElement}return null}function Ln(i,e){var t=i.matches||i.webkitMatchesSelector||i.msMatchesSelector;return t.call(i,e)}function Bi(i){var e=i;if(e.offsetParent!==null)return e.scrollWidth;var t=e.cloneNode(!0);t.style.setProperty("position","absolute"),t.style.setProperty("transform","translate(-9999px, -9999px)"),document.documentElement.appendChild(t);var n=t.scrollWidth;return document.documentElement.removeChild(t),n}const Pi=Object.freeze(Object.defineProperty({__proto__:null,closest:ki,estimateScrollWidth:Bi,matches:Ln},Symbol.toStringTag,{value:"Module"}));/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Ui={BG_FOCUSED:"mdc-ripple-upgraded--background-focused",FG_ACTIVATION:"mdc-ripple-upgraded--foreground-activation",FG_DEACTIVATION:"mdc-ripple-upgraded--foreground-deactivation",ROOT:"mdc-ripple-upgraded",UNBOUNDED:"mdc-ripple-upgraded--unbounded"},wi={VAR_FG_SCALE:"--mdc-ripple-fg-scale",VAR_FG_SIZE:"--mdc-ripple-fg-size",VAR_FG_TRANSLATE_END:"--mdc-ripple-fg-translate-end",VAR_FG_TRANSLATE_START:"--mdc-ripple-fg-translate-start",VAR_LEFT:"--mdc-ripple-left",VAR_TOP:"--mdc-ripple-top"},ln={DEACTIVATION_TIMEOUT_MS:225,FG_DEACTIVATION_MS:150,INITIAL_ORIGIN_SCALE:.6,PADDING:10,TAP_DELAY_MS:300};/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var un=["touchstart","pointerdown","mousedown","keydown"],cn=["touchend","pointerup","mouseup","contextmenu"],Ft=[],Ni=function(i){et(e,i);function e(t){var n=i.call(this,Ne(Ne({},e.defaultAdapter),t))||this;return n.activationAnimationHasEnded=!1,n.activationTimer=0,n.fgDeactivationRemovalTimer=0,n.fgScale="0",n.frame={width:0,height:0},n.initialSize=0,n.layoutFrame=0,n.maxRadius=0,n.unboundedCoords={left:0,top:0},n.activationState=n.defaultActivationState(),n.activationTimerCallback=function(){n.activationAnimationHasEnded=!0,n.runDeactivationUXLogicIfReady()},n.activateHandler=function(a){n.activateImpl(a)},n.deactivateHandler=function(){n.deactivateImpl()},n.focusHandler=function(){n.handleFocus()},n.blurHandler=function(){n.handleBlur()},n.resizeHandler=function(){n.layout()},n}return Object.defineProperty(e,"cssClasses",{get:function(){return Ui},enumerable:!1,configurable:!0}),Object.defineProperty(e,"strings",{get:function(){return wi},enumerable:!1,configurable:!0}),Object.defineProperty(e,"numbers",{get:function(){return ln},enumerable:!1,configurable:!0}),Object.defineProperty(e,"defaultAdapter",{get:function(){return{addClass:function(){},browserSupportsCssVars:function(){return!0},computeBoundingRect:function(){return{top:0,right:0,bottom:0,left:0,width:0,height:0}},containsEventTarget:function(){return!0},deregisterDocumentInteractionHandler:function(){},deregisterInteractionHandler:function(){},deregisterResizeHandler:function(){},getWindowPageOffset:function(){return{x:0,y:0}},isSurfaceActive:function(){return!0},isSurfaceDisabled:function(){return!0},isUnbounded:function(){return!0},registerDocumentInteractionHandler:function(){},registerInteractionHandler:function(){},registerResizeHandler:function(){},removeClass:function(){},updateCssVariable:function(){}}},enumerable:!1,configurable:!0}),e.prototype.init=function(){var t=this,n=this.supportsPressRipple();if(this.registerRootHandlers(n),n){var a=e.cssClasses,r=a.ROOT,l=a.UNBOUNDED;requestAnimationFrame(function(){t.adapter.addClass(r),t.adapter.isUnbounded()&&(t.adapter.addClass(l),t.layoutInternal())})}},e.prototype.destroy=function(){var t=this;if(this.supportsPressRipple()){this.activationTimer&&(clearTimeout(this.activationTimer),this.activationTimer=0,this.adapter.removeClass(e.cssClasses.FG_ACTIVATION)),this.fgDeactivationRemovalTimer&&(clearTimeout(this.fgDeactivationRemovalTimer),this.fgDeactivationRemovalTimer=0,this.adapter.removeClass(e.cssClasses.FG_DEACTIVATION));var n=e.cssClasses,a=n.ROOT,r=n.UNBOUNDED;requestAnimationFrame(function(){t.adapter.removeClass(a),t.adapter.removeClass(r),t.removeCssVars()})}this.deregisterRootHandlers(),this.deregisterDeactivationHandlers()},e.prototype.activate=function(t){this.activateImpl(t)},e.prototype.deactivate=function(){this.deactivateImpl()},e.prototype.layout=function(){var t=this;this.layoutFrame&&cancelAnimationFrame(this.layoutFrame),this.layoutFrame=requestAnimationFrame(function(){t.layoutInternal(),t.layoutFrame=0})},e.prototype.setUnbounded=function(t){var n=e.cssClasses.UNBOUNDED;t?this.adapter.addClass(n):this.adapter.removeClass(n)},e.prototype.handleFocus=function(){var t=this;requestAnimationFrame(function(){return t.adapter.addClass(e.cssClasses.BG_FOCUSED)})},e.prototype.handleBlur=function(){var t=this;requestAnimationFrame(function(){return t.adapter.removeClass(e.cssClasses.BG_FOCUSED)})},e.prototype.supportsPressRipple=function(){return this.adapter.browserSupportsCssVars()},e.prototype.defaultActivationState=function(){return{activationEvent:void 0,hasDeactivationUXRun:!1,isActivated:!1,isProgrammatic:!1,wasActivatedByPointer:!1,wasElementMadeActive:!1}},e.prototype.registerRootHandlers=function(t){var n,a;if(t){try{for(var r=yt(un),l=r.next();!l.done;l=r.next()){var s=l.value;this.adapter.registerInteractionHandler(s,this.activateHandler)}}catch(o){n={error:o}}finally{try{l&&!l.done&&(a=r.return)&&a.call(r)}finally{if(n)throw n.error}}this.adapter.isUnbounded()&&this.adapter.registerResizeHandler(this.resizeHandler)}this.adapter.registerInteractionHandler("focus",this.focusHandler),this.adapter.registerInteractionHandler("blur",this.blurHandler)},e.prototype.registerDeactivationHandlers=function(t){var n,a;if(t.type==="keydown")this.adapter.registerInteractionHandler("keyup",this.deactivateHandler);else try{for(var r=yt(cn),l=r.next();!l.done;l=r.next()){var s=l.value;this.adapter.registerDocumentInteractionHandler(s,this.deactivateHandler)}}catch(o){n={error:o}}finally{try{l&&!l.done&&(a=r.return)&&a.call(r)}finally{if(n)throw n.error}}},e.prototype.deregisterRootHandlers=function(){var t,n;try{for(var a=yt(un),r=a.next();!r.done;r=a.next()){var l=r.value;this.adapter.deregisterInteractionHandler(l,this.activateHandler)}}catch(s){t={error:s}}finally{try{r&&!r.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}this.adapter.deregisterInteractionHandler("focus",this.focusHandler),this.adapter.deregisterInteractionHandler("blur",this.blurHandler),this.adapter.isUnbounded()&&this.adapter.deregisterResizeHandler(this.resizeHandler)},e.prototype.deregisterDeactivationHandlers=function(){var t,n;this.adapter.deregisterInteractionHandler("keyup",this.deactivateHandler);try{for(var a=yt(cn),r=a.next();!r.done;r=a.next()){var l=r.value;this.adapter.deregisterDocumentInteractionHandler(l,this.deactivateHandler)}}catch(s){t={error:s}}finally{try{r&&!r.done&&(n=a.return)&&n.call(a)}finally{if(t)throw t.error}}},e.prototype.removeCssVars=function(){var t=this,n=e.strings,a=Object.keys(n);a.forEach(function(r){r.indexOf("VAR_")===0&&t.adapter.updateCssVariable(n[r],null)})},e.prototype.activateImpl=function(t){var n=this;if(!this.adapter.isSurfaceDisabled()){var a=this.activationState;if(!a.isActivated){var r=this.previousActivationEvent,l=r&&t!==void 0&&r.type!==t.type;if(!l){a.isActivated=!0,a.isProgrammatic=t===void 0,a.activationEvent=t,a.wasActivatedByPointer=a.isProgrammatic?!1:t!==void 0&&(t.type==="mousedown"||t.type==="touchstart"||t.type==="pointerdown");var s=t!==void 0&&Ft.length>0&&Ft.some(function(o){return n.adapter.containsEventTarget(o)});if(s){this.resetActivationState();return}t!==void 0&&(Ft.push(t.target),this.registerDeactivationHandlers(t)),a.wasElementMadeActive=this.checkElementMadeActive(t),a.wasElementMadeActive&&this.animateActivation(),requestAnimationFrame(function(){Ft=[],!a.wasElementMadeActive&&t!==void 0&&(t.key===" "||t.keyCode===32)&&(a.wasElementMadeActive=n.checkElementMadeActive(t),a.wasElementMadeActive&&n.animateActivation()),a.wasElementMadeActive||(n.activationState=n.defaultActivationState())})}}}},e.prototype.checkElementMadeActive=function(t){return t!==void 0&&t.type==="keydown"?this.adapter.isSurfaceActive():!0},e.prototype.animateActivation=function(){var t=this,n=e.strings,a=n.VAR_FG_TRANSLATE_START,r=n.VAR_FG_TRANSLATE_END,l=e.cssClasses,s=l.FG_DEACTIVATION,o=l.FG_ACTIVATION,c=e.numbers.DEACTIVATION_TIMEOUT_MS;this.layoutInternal();var u="",d="";if(!this.adapter.isUnbounded()){var f=this.getFgTranslationCoordinates(),h=f.startPoint,g=f.endPoint;u=h.x+"px, "+h.y+"px",d=g.x+"px, "+g.y+"px"}this.adapter.updateCssVariable(a,u),this.adapter.updateCssVariable(r,d),clearTimeout(this.activationTimer),clearTimeout(this.fgDeactivationRemovalTimer),this.rmBoundedActivationClasses(),this.adapter.removeClass(s),this.adapter.computeBoundingRect(),this.adapter.addClass(o),this.activationTimer=setTimeout(function(){t.activationTimerCallback()},c)},e.prototype.getFgTranslationCoordinates=function(){var t=this.activationState,n=t.activationEvent,a=t.wasActivatedByPointer,r;a?r=Oi(n,this.adapter.getWindowPageOffset(),this.adapter.computeBoundingRect()):r={x:this.frame.width/2,y:this.frame.height/2},r={x:r.x-this.initialSize/2,y:r.y-this.initialSize/2};var l={x:this.frame.width/2-this.initialSize/2,y:this.frame.height/2-this.initialSize/2};return{startPoint:r,endPoint:l}},e.prototype.runDeactivationUXLogicIfReady=function(){var t=this,n=e.cssClasses.FG_DEACTIVATION,a=this.activationState,r=a.hasDeactivationUXRun,l=a.isActivated,s=r||!l;s&&this.activationAnimationHasEnded&&(this.rmBoundedActivationClasses(),this.adapter.addClass(n),this.fgDeactivationRemovalTimer=setTimeout(function(){t.adapter.removeClass(n)},ln.FG_DEACTIVATION_MS))},e.prototype.rmBoundedActivationClasses=function(){var t=e.cssClasses.FG_ACTIVATION;this.adapter.removeClass(t),this.activationAnimationHasEnded=!1,this.adapter.computeBoundingRect()},e.prototype.resetActivationState=function(){var t=this;this.previousActivationEvent=this.activationState.activationEvent,this.activationState=this.defaultActivationState(),setTimeout(function(){return t.previousActivationEvent=void 0},e.numbers.TAP_DELAY_MS)},e.prototype.deactivateImpl=function(){var t=this,n=this.activationState;if(n.isActivated){var a=Ne({},n);n.isProgrammatic?(requestAnimationFrame(function(){t.animateDeactivation(a)}),this.resetActivationState()):(this.deregisterDeactivationHandlers(),requestAnimationFrame(function(){t.activationState.hasDeactivationUXRun=!0,t.animateDeactivation(a),t.resetActivationState()}))}},e.prototype.animateDeactivation=function(t){var n=t.wasActivatedByPointer,a=t.wasElementMadeActive;(n||a)&&this.runDeactivationUXLogicIfReady()},e.prototype.layoutInternal=function(){var t=this;this.frame=this.adapter.computeBoundingRect();var n=Math.max(this.frame.height,this.frame.width),a=function(){var l=Math.sqrt(Math.pow(t.frame.width,2)+Math.pow(t.frame.height,2));return l+e.numbers.PADDING};this.maxRadius=this.adapter.isUnbounded()?n:a();var r=Math.floor(n*e.numbers.INITIAL_ORIGIN_SCALE);this.adapter.isUnbounded()&&r%2!==0?this.initialSize=r-1:this.initialSize=r,this.fgScale=""+this.maxRadius/this.initialSize,this.updateLayoutCssVars()},e.prototype.updateLayoutCssVars=function(){var t=e.strings,n=t.VAR_FG_SIZE,a=t.VAR_LEFT,r=t.VAR_TOP,l=t.VAR_FG_SCALE;this.adapter.updateCssVariable(n,this.initialSize+"px"),this.adapter.updateCssVariable(l,this.fgScale),this.adapter.isUnbounded()&&(this.unboundedCoords={left:Math.round(this.frame.width/2-this.initialSize/2),top:Math.round(this.frame.height/2-this.initialSize/2)},this.adapter.updateCssVariable(a,this.unboundedCoords.left+"px"),this.adapter.updateCssVariable(r,this.unboundedCoords.top+"px"))},e}(Fi);const{applyPassive:Dt}=Mi,{matches:Hi}=Pi;function dn(i,{ripple:e=!0,surface:t=!1,unbounded:n=!1,disabled:a=!1,color:r,active:l,rippleElement:s,eventTarget:o,activeTarget:c,addClass:u=g=>i.classList.add(g),removeClass:d=g=>i.classList.remove(g),addStyle:f=(g,I)=>i.style.setProperty(g,I),initPromise:h=Promise.resolve()}={}){let g,I=De("SMUI:addLayoutListener"),v,C=l,p=o,b=c;function R(){t?(u("mdc-ripple-surface"),r==="primary"?(u("smui-ripple-surface--primary"),d("smui-ripple-surface--secondary")):r==="secondary"?(d("smui-ripple-surface--primary"),u("smui-ripple-surface--secondary")):(d("smui-ripple-surface--primary"),d("smui-ripple-surface--secondary"))):(d("mdc-ripple-surface"),d("smui-ripple-surface--primary"),d("smui-ripple-surface--secondary")),g&&C!==l&&(C=l,l?g.activate():l===!1&&g.deactivate()),e&&!g?(g=new Ni({addClass:u,browserSupportsCssVars:()=>Ti(window),computeBoundingRect:()=>(s||i).getBoundingClientRect(),containsEventTarget:k=>i.contains(k),deregisterDocumentInteractionHandler:(k,j)=>document.documentElement.removeEventListener(k,j,Dt()),deregisterInteractionHandler:(k,j)=>(o||i).removeEventListener(k,j,Dt()),deregisterResizeHandler:k=>window.removeEventListener("resize",k),getWindowPageOffset:()=>({x:window.pageXOffset,y:window.pageYOffset}),isSurfaceActive:()=>l??Hi(c||i,":active"),isSurfaceDisabled:()=>!!a,isUnbounded:()=>!!n,registerDocumentInteractionHandler:(k,j)=>document.documentElement.addEventListener(k,j,Dt()),registerInteractionHandler:(k,j)=>(o||i).addEventListener(k,j,Dt()),registerResizeHandler:k=>window.addEventListener("resize",k),removeClass:d,updateCssVariable:f}),h.then(()=>{g&&(g.init(),g.setUnbounded(n))})):g&&!e&&h.then(()=>{g&&(g.destroy(),g=void 0)}),g&&(p!==o||b!==c)&&(p=o,b=c,g.destroy(),requestAnimationFrame(()=>{g&&(g.init(),g.setUnbounded(n))})),!e&&n&&u("mdc-ripple-upgraded--unbounded")}R(),I&&(v=I(S));function S(){g&&g.layout()}return{update(k){({ripple:e,surface:t,unbounded:n,disabled:a,color:r,active:l,rippleElement:s,eventTarget:o,activeTarget:c,addClass:u,removeClass:d,addStyle:f,initPromise:h}=Object.assign({ripple:!0,surface:!1,unbounded:!1,disabled:!1,color:void 0,active:void 0,rippleElement:void 0,eventTarget:void 0,activeTarget:void 0,addClass:j=>i.classList.add(j),removeClass:j=>i.classList.remove(j),addStyle:(j,J)=>i.style.setProperty(j,J),initPromise:Promise.resolve()},k)),R()},destroy(){g&&(g.destroy(),g=void 0,d("mdc-ripple-surface"),d("smui-ripple-surface--primary"),d("smui-ripple-surface--secondary")),v&&v()}}}function ji(i){let e,t,n,a,r;const l=i[7].default,s=ue(l,i,i[6],null);let o=[{href:i[1]},i[4]],c={};for(let u=0;u<o.length;u+=1)c=B(c,o[u]);return{c(){e=ye("a"),s&&s.c(),this.h()},l(u){e=Le(u,"A",{href:!0});var d=ce(e);s&&s.l(d),d.forEach(E),this.h()},h(){re(e,c)},m(u,d){M(u,e,d),s&&s.m(e,null),i[8](e),n=!0,a||(r=[ne(t=yn.call(null,e,i[0])),ne(i[3].call(null,e))],a=!0)},p(u,[d]){s&&s.p&&(!n||d&64)&&de(s,l,u,u[6],n?me(l,u[6],d,null):fe(u[6]),null),re(e,c=Ae(o,[(!n||d&2)&&{href:u[1]},d&16&&u[4]])),t&&Be(t.update)&&d&1&&t.update.call(null,u[0])},i(u){n||(y(s,u),n=!0)},o(u){L(s,u),n=!1},d(u){u&&E(e),s&&s.d(u),i[8](null),a=!1,Ve(r)}}}function Gi(i,e,t){const n=["use","href","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e,{use:s=[]}=e,{href:o="javascript:void(0);"}=e;const c=Xt(Ee());let u;function d(){return u}function f(h){he[h?"unshift":"push"](()=>{u=h,t(2,u)})}return i.$$set=h=>{e=B(B({},e),Se(h)),t(4,a=K(e,n)),"use"in h&&t(0,s=h.use),"href"in h&&t(1,o=h.href),"$$scope"in h&&t(6,l=h.$$scope)},[s,o,u,c,a,d,l,r,f]}let zi=class extends ae{constructor(e){super(),oe(this,e,Gi,ji,le,{use:0,href:1,getElement:5})}get getElement(){return this.$$.ctx[5]}};function Vi(i){let e,t,n,a,r;const l=i[6].default,s=ue(l,i,i[5],null);let o=[i[3]],c={};for(let u=0;u<o.length;u+=1)c=B(c,o[u]);return{c(){e=ye("button"),s&&s.c(),this.h()},l(u){e=Le(u,"BUTTON",{});var d=ce(e);s&&s.l(d),d.forEach(E),this.h()},h(){re(e,c)},m(u,d){M(u,e,d),s&&s.m(e,null),e.autofocus&&e.focus(),i[7](e),n=!0,a||(r=[ne(t=yn.call(null,e,i[0])),ne(i[2].call(null,e))],a=!0)},p(u,[d]){s&&s.p&&(!n||d&32)&&de(s,l,u,u[5],n?me(l,u[5],d,null):fe(u[5]),null),re(e,c=Ae(o,[d&8&&u[3]])),t&&Be(t.update)&&d&1&&t.update.call(null,u[0])},i(u){n||(y(s,u),n=!0)},o(u){L(s,u),n=!1},d(u){u&&E(e),s&&s.d(u),i[7](null),a=!1,Ve(r)}}}function Wi(i,e,t){const n=["use","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e,{use:s=[]}=e;const o=Xt(Ee());let c;function u(){return c}function d(f){he[f?"unshift":"push"](()=>{c=f,t(1,c)})}return i.$$set=f=>{e=B(B({},e),Se(f)),t(3,a=K(e,n)),"use"in f&&t(0,s=f.use),"$$scope"in f&&t(5,l=f.$$scope)},[s,c,o,a,u,l,r,d]}let Xi=class extends ae{constructor(e){super(),oe(this,e,Wi,Vi,le,{use:0,getElement:4})}get getElement(){return this.$$.ctx[4]}};const Ki=zi,qi=Xi;function fn(i){let e;return{c(){e=ye("div"),this.h()},l(t){e=Le(t,"DIV",{class:!0}),ce(e).forEach(E),this.h()},h(){Me(e,"class","mdc-icon-button__touch")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function Zi(i){let e,t,n,a;const r=i[32].default,l=ue(r,i,i[36],null);let s=i[8]&&fn();return{c(){e=ye("div"),t=ve(),l&&l.c(),s&&s.c(),n=Ie(),this.h()},l(o){e=Le(o,"DIV",{class:!0}),ce(e).forEach(E),t=Ce(o),l&&l.l(o),s&&s.l(o),n=Ie(),this.h()},h(){Me(e,"class","mdc-icon-button__ripple")},m(o,c){M(o,e,c),M(o,t,c),l&&l.m(o,c),s&&s.m(o,c),M(o,n,c),a=!0},p(o,c){l&&l.p&&(!a||c[1]&32)&&de(l,r,o,o[36],a?me(r,o[36],c,null):fe(o[36]),null),o[8]?s||(s=fn(),s.c(),s.m(n.parentNode,n)):s&&(s.d(1),s=null)},i(o){a||(y(l,o),a=!0)},o(o){L(l,o),a=!1},d(o){o&&E(e),o&&E(t),l&&l.d(o),s&&s.d(o),o&&E(n)}}}function Ji(i){let e,t,n;const a=[{use:[[dn,{ripple:i[4],unbounded:!0,color:i[5],disabled:!!i[28].disabled,addClass:i[25],removeClass:i[26],addStyle:i[27]}],i[21],...i[1]]},{class:rn({[i[2]]:!0,"mdc-icon-button":!0,"mdc-icon-button--on":!i[22](i[0])&&i[0],"mdc-icon-button--touch":i[8],"mdc-icon-button--display-flex":i[9],"smui-icon-button--size-button":i[10]==="button","mdc-icon-button--reduced-size":i[10]==="mini"||i[10]==="button","mdc-card__action":i[23]==="card:action","mdc-card__action--icon":i[23]==="card:action","mdc-top-app-bar__navigation-icon":i[23]==="top-app-bar:navigation","mdc-top-app-bar__action-item":i[23]==="top-app-bar:action","mdc-snackbar__dismiss":i[23]==="snackbar:actions","mdc-data-table__pagination-button":i[23]==="data-table:pagination","mdc-data-table__sort-icon-button":i[23]==="data-table:sortable-header-cell","mdc-dialog__close":i[23]==="dialog:header"&&i[12]==="close",...i[17]})},{style:Object.entries(i[18]).map(mn).concat([i[3]]).join(" ")},{"aria-pressed":i[22](i[0])?null:i[0]?"true":"false"},{"aria-label":i[0]?i[6]:i[7]},{"data-aria-label-on":i[6]},{"data-aria-label-off":i[7]},{"aria-describedby":i[24]},{href:i[11]},i[20],i[19],i[28]];var r=i[13];function l(s){let o={$$slots:{default:[Zi]},$$scope:{ctx:s}};for(let c=0;c<a.length;c+=1)o=B(o,a[c]);return{props:o}}return r&&(e=Pe(r,l(i)),i[33](e),e.$on("click",i[34]),e.$on("click",i[35])),{c(){e&&w(e.$$.fragment),t=Ie()},l(s){e&&V(e.$$.fragment,s),t=Ie()},m(s,o){e&&N(e,s,o),M(s,t,o),n=!0},p(s,o){const c=o[0]&536748031?Ae(a,[o[0]&505413682&&{use:[[dn,{ripple:s[4],unbounded:!0,color:s[5],disabled:!!s[28].disabled,addClass:s[25],removeClass:s[26],addStyle:s[27]}],s[21],...s[1]]},o[0]&12719877&&{class:rn({[s[2]]:!0,"mdc-icon-button":!0,"mdc-icon-button--on":!s[22](s[0])&&s[0],"mdc-icon-button--touch":s[8],"mdc-icon-button--display-flex":s[9],"smui-icon-button--size-button":s[10]==="button","mdc-icon-button--reduced-size":s[10]==="mini"||s[10]==="button","mdc-card__action":s[23]==="card:action","mdc-card__action--icon":s[23]==="card:action","mdc-top-app-bar__navigation-icon":s[23]==="top-app-bar:navigation","mdc-top-app-bar__action-item":s[23]==="top-app-bar:action","mdc-snackbar__dismiss":s[23]==="snackbar:actions","mdc-data-table__pagination-button":s[23]==="data-table:pagination","mdc-data-table__sort-icon-button":s[23]==="data-table:sortable-header-cell","mdc-dialog__close":s[23]==="dialog:header"&&s[12]==="close",...s[17]})},o[0]&262152&&{style:Object.entries(s[18]).map(mn).concat([s[3]]).join(" ")},o[0]&4194305&&{"aria-pressed":s[22](s[0])?null:s[0]?"true":"false"},o[0]&193&&{"aria-label":s[0]?s[6]:s[7]},o[0]&64&&{"data-aria-label-on":s[6]},o[0]&128&&{"data-aria-label-off":s[7]},o[0]&16777216&&{"aria-describedby":s[24]},o[0]&2048&&{href:s[11]},o[0]&1048576&&be(s[20]),o[0]&524288&&be(s[19]),o[0]&268435456&&be(s[28])]):{};if(o[0]&256|o[1]&32&&(c.$$scope={dirty:o,ctx:s}),r!==(r=s[13])){if(e){ht();const u=e;L(u.$$.fragment,1,0,()=>{H(u,1)}),mt()}r?(e=Pe(r,l(s)),s[33](e),e.$on("click",s[34]),e.$on("click",s[35]),w(e.$$.fragment),y(e.$$.fragment,1),N(e,t.parentNode,t)):e=null}else r&&e.$set(c)},i(s){n||(e&&y(e.$$.fragment,s),n=!0)},o(s){e&&L(e.$$.fragment,s),n=!1},d(s){i[33](null),s&&E(t),e&&H(e,s)}}}const mn=([i,e])=>`${i}: ${e};`;function Qi(i,e,t){let n;const a=["use","class","style","ripple","color","toggle","pressed","ariaLabelOn","ariaLabelOff","touch","displayFlex","size","href","action","component","getElement"];let r=K(e,a),{$$slots:l={},$$scope:s}=e;const o=Xt(Ee());let c=()=>{};function u(A){return A===c}let{use:d=[]}=e,{class:f=""}=e,{style:h=""}=e,{ripple:g=!0}=e,{color:I=void 0}=e,{toggle:v=!1}=e,{pressed:C=c}=e,{ariaLabelOn:p=void 0}=e,{ariaLabelOff:b=void 0}=e,{touch:R=!1}=e,{displayFlex:S=!0}=e,{size:k="normal"}=e,{href:j=void 0}=e,{action:J=void 0}=e,$,q,X={},Z={},Q={},T=De("SMUI:icon-button:context"),z=De("SMUI:icon-button:aria-describedby"),{component:P=j==null?qi:Ki}=e,Y=r.disabled;pe("SMUI:icon:context","icon-button");let ie=null;At(()=>{q&&q.destroy()});function Ke(A){return A in X?X[A]:we().classList.contains(A)}function je(A){X[A]||t(17,X[A]=!0,X)}function qe(A){(!(A in X)||X[A])&&t(17,X[A]=!1,X)}function Ze(A,ge){Z[A]!=ge&&(ge===""||ge==null?(delete Z[A],t(18,Z)):t(18,Z[A]=ge,Z))}function Je(A){var ge;return A in Q?(ge=Q[A])!==null&&ge!==void 0?ge:null:we().getAttribute(A)}function F(A,ge){Q[A]!==ge&&t(19,Q[A]=ge,Q)}function Ue(A){t(0,C=A.isOn)}function we(){return $.getElement()}function gt(A){he[A?"unshift":"push"](()=>{$=A,t(15,$)})}const _t=()=>q&&q.handleClick(),bt=()=>T==="top-app-bar:navigation"&&an(we(),"SMUITopAppBarIconButton:nav");return i.$$set=A=>{e=B(B({},e),Se(A)),t(28,r=K(e,a)),"use"in A&&t(1,d=A.use),"class"in A&&t(2,f=A.class),"style"in A&&t(3,h=A.style),"ripple"in A&&t(4,g=A.ripple),"color"in A&&t(5,I=A.color),"toggle"in A&&t(29,v=A.toggle),"pressed"in A&&t(0,C=A.pressed),"ariaLabelOn"in A&&t(6,p=A.ariaLabelOn),"ariaLabelOff"in A&&t(7,b=A.ariaLabelOff),"touch"in A&&t(8,R=A.touch),"displayFlex"in A&&t(9,S=A.displayFlex),"size"in A&&t(10,k=A.size),"href"in A&&t(11,j=A.href),"action"in A&&t(12,J=A.action),"component"in A&&t(13,P=A.component),"$$scope"in A&&t(36,s=A.$$scope)},i.$$.update=()=>{if(i.$$.dirty[0]&4096&&t(20,n=(()=>{if(T==="data-table:pagination")switch(J){case"first-page":return{"data-first-page":"true"};case"prev-page":return{"data-prev-page":"true"};case"next-page":return{"data-next-page":"true"};case"last-page":return{"data-last-page":"true"};default:return{"data-action":"true"}}else return T==="dialog:header"?{"data-mdc-dialog-action":J}:{action:J}})()),Y!==r.disabled){const A=we();"blur"in A&&A.blur(),t(30,Y=r.disabled)}i.$$.dirty[0]&536969216|i.$$.dirty[1]&1&&$&&we()&&v!==ie&&(v&&!q?(t(16,q=new yi({addClass:je,hasClass:Ke,notifyChange:A=>{Ue(A),an(we(),"SMUIIconButtonToggle:change",A,void 0,!0)},removeClass:qe,getAttr:Je,setAttr:F})),q.init()):!v&&q&&(q.destroy(),t(16,q=void 0),t(17,X={}),t(19,Q={})),t(31,ie=v)),i.$$.dirty[0]&65537&&q&&!u(C)&&q.isOn()!==C&&q.toggle(C)},[C,d,f,h,g,I,p,b,R,S,k,j,J,P,we,$,q,X,Z,Q,n,o,u,T,z,je,qe,Ze,r,v,Y,ie,l,gt,_t,bt,s]}class kt extends ae{constructor(e){super(),oe(this,e,Qi,Ji,le,{use:1,class:2,style:3,ripple:4,color:5,toggle:29,pressed:0,ariaLabelOn:6,ariaLabelOff:7,touch:8,displayFlex:9,size:10,href:11,action:12,component:13,getElement:14},null,[-1,-1])}get getElement(){return this.$$.ctx[14]}}function Yi(i){let e;const t=i[11].default,n=ue(t,i,i[13],null);return{c(){n&&n.c()},l(a){n&&n.l(a)},m(a,r){n&&n.m(a,r),e=!0},p(a,r){n&&n.p&&(!e||r&8192)&&de(n,t,a,a[13],e?me(t,a[13],r,null):fe(a[13]),null)},i(a){e||(y(n,a),e=!0)},o(a){L(n,a),e=!1},d(a){n&&n.d(a)}}}function xi(i){let e,t,n;const a=[{tag:i[4]},{use:[i[6],...i[0]]},{class:ze({[i[1]]:!0,"mdc-button__icon":i[8]==="button","mdc-fab__icon":i[8]==="fab","mdc-icon-button__icon":i[8]==="icon-button","mdc-icon-button__icon--on":i[8]==="icon-button"&&i[2],"mdc-tab__icon":i[8]==="tab","mdc-banner__icon":i[8]==="banner","mdc-segmented-button__icon":i[8]==="segmented-button"})},{"aria-hidden":"true"},i[7]?{focusable:"false",tabindex:"-1"}:{},i[9]];var r=i[3];function l(s){let o={$$slots:{default:[Yi]},$$scope:{ctx:s}};for(let c=0;c<a.length;c+=1)o=B(o,a[c]);return{props:o}}return r&&(e=Pe(r,l(i)),i[12](e)),{c(){e&&w(e.$$.fragment),t=Ie()},l(s){e&&V(e.$$.fragment,s),t=Ie()},m(s,o){e&&N(e,s,o),M(s,t,o),n=!0},p(s,[o]){const c=o&983?Ae(a,[o&16&&{tag:s[4]},o&65&&{use:[s[6],...s[0]]},o&262&&{class:ze({[s[1]]:!0,"mdc-button__icon":s[8]==="button","mdc-fab__icon":s[8]==="fab","mdc-icon-button__icon":s[8]==="icon-button","mdc-icon-button__icon--on":s[8]==="icon-button"&&s[2],"mdc-tab__icon":s[8]==="tab","mdc-banner__icon":s[8]==="banner","mdc-segmented-button__icon":s[8]==="segmented-button"})},a[3],o&128&&be(s[7]?{focusable:"false",tabindex:"-1"}:{}),o&512&&be(s[9])]):{};if(o&8192&&(c.$$scope={dirty:o,ctx:s}),r!==(r=s[3])){if(e){ht();const u=e;L(u.$$.fragment,1,0,()=>{H(u,1)}),mt()}r?(e=Pe(r,l(s)),s[12](e),w(e.$$.fragment),y(e.$$.fragment,1),N(e,t.parentNode,t)):e=null}else r&&e.$set(c)},i(s){n||(e&&y(e.$$.fragment,s),n=!0)},o(s){e&&L(e.$$.fragment,s),n=!1},d(s){i[12](null),s&&E(t),e&&H(e,s)}}}function $i(i,e,t){const n=["use","class","on","component","tag","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e;const s=pt(Ee());let{use:o=[]}=e,{class:c=""}=e,{on:u=!1}=e,d,{component:f=ft}=e,{tag:h=f===ft?"i":void 0}=e;const g=f===Nt,I=De("SMUI:icon:context");function v(){return d.getElement()}function C(p){he[p?"unshift":"push"](()=>{d=p,t(5,d)})}return i.$$set=p=>{e=B(B({},e),Se(p)),t(9,a=K(e,n)),"use"in p&&t(0,o=p.use),"class"in p&&t(1,c=p.class),"on"in p&&t(2,u=p.on),"component"in p&&t(3,f=p.component),"tag"in p&&t(4,h=p.tag),"$$scope"in p&&t(13,l=p.$$scope)},[o,c,u,f,h,d,s,g,I,a,v,r,C,l]}class Kt extends ae{constructor(e){super(),oe(this,e,$i,xi,le,{use:0,class:1,on:2,component:3,tag:4,getElement:10})}get getElement(){return this.$$.ctx[10]}}function es(i){let e,t,n,a,r;const l=i[6].default,s=ue(l,i,i[5],null);let o=[i[3]],c={};for(let u=0;u<o.length;u+=1)c=B(c,o[u]);return{c(){e=Ut("svg"),s&&s.c(),this.h()},l(u){e=wt(u,"svg",{});var d=ce(e);s&&s.l(d),d.forEach(E),this.h()},h(){Qt(e,c)},m(u,d){M(u,e,d),s&&s.m(e,null),i[7](e),n=!0,a||(r=[ne(t=Vt.call(null,e,i[0])),ne(i[2].call(null,e))],a=!0)},p(u,[d]){s&&s.p&&(!n||d&32)&&de(s,l,u,u[5],n?me(l,u[5],d,null):fe(u[5]),null),Qt(e,c=Ae(o,[d&8&&u[3]])),t&&Be(t.update)&&d&1&&t.update.call(null,u[0])},i(u){n||(y(s,u),n=!0)},o(u){L(s,u),n=!1},d(u){u&&E(e),s&&s.d(u),i[7](null),a=!1,Ve(r)}}}function ts(i,e,t){const n=["use","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e,{use:s=[]}=e;const o=pt(Ee());let c;function u(){return c}function d(f){he[f?"unshift":"push"](()=>{c=f,t(1,c)})}return i.$$set=f=>{e=B(B({},e),Se(f)),t(3,a=K(e,n)),"use"in f&&t(0,s=f.use),"$$scope"in f&&t(5,l=f.$$scope)},[s,c,o,a,u,l,r,d]}class Nt extends ae{constructor(e){super(),oe(this,e,ts,es,le,{use:0,getElement:4})}get getElement(){return this.$$.ctx[4]}}var ns="M12,18V6A6,6 0 0,1 18,12A6,6 0 0,1 12,18M20,15.31L23.31,12L20,8.69V4H15.31L12,0.69L8.69,4H4V8.69L0.69,12L4,15.31V20H8.69L12,23.31L15.31,20H20V15.31Z",is="M12,2A10,10 0 0,0 2,12C2,16.42 4.87,20.17 8.84,21.5C9.34,21.58 9.5,21.27 9.5,21C9.5,20.77 9.5,20.14 9.5,19.31C6.73,19.91 6.14,17.97 6.14,17.97C5.68,16.81 5.03,16.5 5.03,16.5C4.12,15.88 5.1,15.9 5.1,15.9C6.1,15.97 6.63,16.93 6.63,16.93C7.5,18.45 8.97,18 9.54,17.76C9.63,17.11 9.89,16.67 10.17,16.42C7.95,16.17 5.62,15.31 5.62,11.5C5.62,10.39 6,9.5 6.65,8.79C6.55,8.54 6.2,7.5 6.75,6.15C6.75,6.15 7.59,5.88 9.5,7.17C10.29,6.95 11.15,6.84 12,6.84C12.85,6.84 13.71,6.95 14.5,7.17C16.41,5.88 17.25,6.15 17.25,6.15C17.8,7.5 17.45,8.54 17.35,8.79C18,9.5 18.38,10.39 18.38,11.5C18.38,15.32 16.04,16.16 13.81,16.41C14.17,16.72 14.5,17.33 14.5,18.26C14.5,19.6 14.5,20.68 14.5,21C14.5,21.27 14.66,21.59 15.17,21.5C19.14,20.16 22,16.42 22,12A10,10 0 0,0 12,2Z",ss="M17.65,6.35C16.2,4.9 14.21,4 12,4A8,8 0 0,0 4,12A8,8 0 0,0 12,20C15.73,20 18.84,17.45 19.73,14H17.65C16.83,16.33 14.61,18 12,18A6,6 0 0,1 6,12A6,6 0 0,1 12,6C13.66,6 15.14,6.69 16.22,7.78L13,11H20V4L17.65,6.35Z";/**
 * @license
 * Copyright 2020 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Gt="mdc-dom-focus-sentinel",rs=function(){function i(e,t){t===void 0&&(t={}),this.root=e,this.options=t,this.elFocusedBeforeTrapFocus=null}return i.prototype.trapFocus=function(){var e=this.getFocusableElements(this.root);if(e.length===0)throw new Error("FocusTrap: Element must have at least one focusable child.");this.elFocusedBeforeTrapFocus=document.activeElement instanceof HTMLElement?document.activeElement:null,this.wrapTabFocus(this.root),this.options.skipInitialFocus||this.focusInitialElement(e,this.options.initialFocusEl)},i.prototype.releaseFocus=function(){[].slice.call(this.root.querySelectorAll("."+Gt)).forEach(function(e){e.parentElement.removeChild(e)}),!this.options.skipRestoreFocus&&this.elFocusedBeforeTrapFocus&&this.elFocusedBeforeTrapFocus.focus()},i.prototype.wrapTabFocus=function(e){var t=this,n=this.createSentinel(),a=this.createSentinel();n.addEventListener("focus",function(){var r=t.getFocusableElements(e);r.length>0&&r[r.length-1].focus()}),a.addEventListener("focus",function(){var r=t.getFocusableElements(e);r.length>0&&r[0].focus()}),e.insertBefore(n,e.children[0]),e.appendChild(a)},i.prototype.focusInitialElement=function(e,t){var n=0;t&&(n=Math.max(e.indexOf(t),0)),e[n].focus()},i.prototype.getFocusableElements=function(e){var t=[].slice.call(e.querySelectorAll("[autofocus], [tabindex], a, input, textarea, select, button"));return t.filter(function(n){var a=n.getAttribute("aria-disabled")==="true"||n.getAttribute("disabled")!=null||n.getAttribute("hidden")!=null||n.getAttribute("aria-hidden")==="true",r=n.tabIndex>=0&&n.getBoundingClientRect().width>0&&!n.classList.contains(Gt)&&!a,l=!1;if(r){var s=getComputedStyle(n);l=s.display==="none"||s.visibility==="hidden"}return r&&!l})},i.prototype.createSentinel=function(){var e=document.createElement("div");return e.setAttribute("tabindex","0"),e.setAttribute("aria-hidden","true"),e.classList.add(Gt),e},i}();const as=Object.freeze(Object.defineProperty({__proto__:null,FocusTrap:rs},Symbol.toStringTag,{value:"Module"}));/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var tt,xe,W={LIST_ITEM_ACTIVATED_CLASS:"mdc-list-item--activated",LIST_ITEM_CLASS:"mdc-list-item",LIST_ITEM_DISABLED_CLASS:"mdc-list-item--disabled",LIST_ITEM_SELECTED_CLASS:"mdc-list-item--selected",LIST_ITEM_TEXT_CLASS:"mdc-list-item__text",LIST_ITEM_PRIMARY_TEXT_CLASS:"mdc-list-item__primary-text",ROOT:"mdc-list"};tt={},tt[""+W.LIST_ITEM_ACTIVATED_CLASS]="mdc-list-item--activated",tt[""+W.LIST_ITEM_CLASS]="mdc-list-item",tt[""+W.LIST_ITEM_DISABLED_CLASS]="mdc-list-item--disabled",tt[""+W.LIST_ITEM_SELECTED_CLASS]="mdc-list-item--selected",tt[""+W.LIST_ITEM_PRIMARY_TEXT_CLASS]="mdc-list-item__primary-text",tt[""+W.ROOT]="mdc-list";var dt=(xe={},xe[""+W.LIST_ITEM_ACTIVATED_CLASS]="mdc-deprecated-list-item--activated",xe[""+W.LIST_ITEM_CLASS]="mdc-deprecated-list-item",xe[""+W.LIST_ITEM_DISABLED_CLASS]="mdc-deprecated-list-item--disabled",xe[""+W.LIST_ITEM_SELECTED_CLASS]="mdc-deprecated-list-item--selected",xe[""+W.LIST_ITEM_TEXT_CLASS]="mdc-deprecated-list-item__text",xe[""+W.LIST_ITEM_PRIMARY_TEXT_CLASS]="mdc-deprecated-list-item__primary-text",xe[""+W.ROOT]="mdc-deprecated-list",xe),nt={ACTION_EVENT:"MDCList:action",SELECTION_CHANGE_EVENT:"MDCList:selectionChange",ARIA_CHECKED:"aria-checked",ARIA_CHECKED_CHECKBOX_SELECTOR:'[role="checkbox"][aria-checked="true"]',ARIA_CHECKED_RADIO_SELECTOR:'[role="radio"][aria-checked="true"]',ARIA_CURRENT:"aria-current",ARIA_DISABLED:"aria-disabled",ARIA_ORIENTATION:"aria-orientation",ARIA_ORIENTATION_HORIZONTAL:"horizontal",ARIA_ROLE_CHECKBOX_SELECTOR:'[role="checkbox"]',ARIA_SELECTED:"aria-selected",ARIA_INTERACTIVE_ROLES_SELECTOR:'[role="listbox"], [role="menu"]',ARIA_MULTI_SELECTABLE_SELECTOR:'[aria-multiselectable="true"]',CHECKBOX_RADIO_SELECTOR:'input[type="checkbox"], input[type="radio"]',CHECKBOX_SELECTOR:'input[type="checkbox"]',CHILD_ELEMENTS_TO_TOGGLE_TABINDEX:`
    .`+W.LIST_ITEM_CLASS+` button:not(:disabled),
    .`+W.LIST_ITEM_CLASS+` a,
    .`+dt[W.LIST_ITEM_CLASS]+` button:not(:disabled),
    .`+dt[W.LIST_ITEM_CLASS]+` a
  `,DEPRECATED_SELECTOR:".mdc-deprecated-list",FOCUSABLE_CHILD_ELEMENTS:`
    .`+W.LIST_ITEM_CLASS+` button:not(:disabled),
    .`+W.LIST_ITEM_CLASS+` a,
    .`+W.LIST_ITEM_CLASS+` input[type="radio"]:not(:disabled),
    .`+W.LIST_ITEM_CLASS+` input[type="checkbox"]:not(:disabled),
    .`+dt[W.LIST_ITEM_CLASS]+` button:not(:disabled),
    .`+dt[W.LIST_ITEM_CLASS]+` a,
    .`+dt[W.LIST_ITEM_CLASS]+` input[type="radio"]:not(:disabled),
    .`+dt[W.LIST_ITEM_CLASS]+` input[type="checkbox"]:not(:disabled)
  `,RADIO_SELECTOR:'input[type="radio"]',SELECTED_ITEM_SELECTOR:'[aria-selected="true"], [aria-current="true"]'},ee={UNSET_INDEX:-1,TYPEAHEAD_BUFFER_CLEAR_TIMEOUT_MS:300};/**
 * @license
 * Copyright 2020 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var G={UNKNOWN:"Unknown",BACKSPACE:"Backspace",ENTER:"Enter",SPACEBAR:"Spacebar",PAGE_UP:"PageUp",PAGE_DOWN:"PageDown",END:"End",HOME:"Home",ARROW_LEFT:"ArrowLeft",ARROW_UP:"ArrowUp",ARROW_RIGHT:"ArrowRight",ARROW_DOWN:"ArrowDown",DELETE:"Delete",ESCAPE:"Escape",TAB:"Tab"},Te=new Set;Te.add(G.BACKSPACE);Te.add(G.ENTER);Te.add(G.SPACEBAR);Te.add(G.PAGE_UP);Te.add(G.PAGE_DOWN);Te.add(G.END);Te.add(G.HOME);Te.add(G.ARROW_LEFT);Te.add(G.ARROW_UP);Te.add(G.ARROW_RIGHT);Te.add(G.ARROW_DOWN);Te.add(G.DELETE);Te.add(G.ESCAPE);Te.add(G.TAB);var Re={BACKSPACE:8,ENTER:13,SPACEBAR:32,PAGE_UP:33,PAGE_DOWN:34,END:35,HOME:36,ARROW_LEFT:37,ARROW_UP:38,ARROW_RIGHT:39,ARROW_DOWN:40,DELETE:46,ESCAPE:27,TAB:9},Oe=new Map;Oe.set(Re.BACKSPACE,G.BACKSPACE);Oe.set(Re.ENTER,G.ENTER);Oe.set(Re.SPACEBAR,G.SPACEBAR);Oe.set(Re.PAGE_UP,G.PAGE_UP);Oe.set(Re.PAGE_DOWN,G.PAGE_DOWN);Oe.set(Re.END,G.END);Oe.set(Re.HOME,G.HOME);Oe.set(Re.ARROW_LEFT,G.ARROW_LEFT);Oe.set(Re.ARROW_UP,G.ARROW_UP);Oe.set(Re.ARROW_RIGHT,G.ARROW_RIGHT);Oe.set(Re.ARROW_DOWN,G.ARROW_DOWN);Oe.set(Re.DELETE,G.DELETE);Oe.set(Re.ESCAPE,G.ESCAPE);Oe.set(Re.TAB,G.TAB);var at=new Set;at.add(G.PAGE_UP);at.add(G.PAGE_DOWN);at.add(G.END);at.add(G.HOME);at.add(G.ARROW_LEFT);at.add(G.ARROW_UP);at.add(G.ARROW_RIGHT);at.add(G.ARROW_DOWN);function _e(i){var e=i.key;if(Te.has(e))return e;var t=Oe.get(i.keyCode);return t||G.UNKNOWN}/**
 * @license
 * Copyright 2020 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var os=["input","button","textarea","select"],ke=function(i){var e=i.target;if(e){var t=(""+e.tagName).toLowerCase();os.indexOf(t)===-1&&i.preventDefault()}};/**
 * @license
 * Copyright 2020 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */function ls(){var i={bufferClearTimeout:0,currentFirstChar:"",sortedIndexCursor:0,typeaheadBuffer:""};return i}function us(i,e){for(var t=new Map,n=0;n<i;n++){var a=e(n).trim();if(a){var r=a[0].toLowerCase();t.has(r)||t.set(r,[]),t.get(r).push({text:a.toLowerCase(),index:n})}}return t.forEach(function(l){l.sort(function(s,o){return s.index-o.index})}),t}function zt(i,e){var t=i.nextChar,n=i.focusItemAtIndex,a=i.sortedIndexByFirstChar,r=i.focusedItemIndex,l=i.skipFocus,s=i.isItemAtIndexDisabled;clearTimeout(e.bufferClearTimeout),e.bufferClearTimeout=setTimeout(function(){On(e)},ee.TYPEAHEAD_BUFFER_CLEAR_TIMEOUT_MS),e.typeaheadBuffer=e.typeaheadBuffer+t;var o;return e.typeaheadBuffer.length===1?o=cs(a,r,s,e):o=ds(a,s,e),o!==-1&&!l&&n(o),o}function cs(i,e,t,n){var a=n.typeaheadBuffer[0],r=i.get(a);if(!r)return-1;if(a===n.currentFirstChar&&r[n.sortedIndexCursor].index===e){n.sortedIndexCursor=(n.sortedIndexCursor+1)%r.length;var l=r[n.sortedIndexCursor].index;if(!t(l))return l}n.currentFirstChar=a;var s=-1,o;for(o=0;o<r.length;o++)if(!t(r[o].index)){s=o;break}for(;o<r.length;o++)if(r[o].index>e&&!t(r[o].index)){s=o;break}return s!==-1?(n.sortedIndexCursor=s,r[n.sortedIndexCursor].index):-1}function ds(i,e,t){var n=t.typeaheadBuffer[0],a=i.get(n);if(!a)return-1;var r=a[t.sortedIndexCursor];if(r.text.lastIndexOf(t.typeaheadBuffer,0)===0&&!e(r.index))return r.index;for(var l=(t.sortedIndexCursor+1)%a.length,s=-1;l!==t.sortedIndexCursor;){var o=a[l],c=o.text.lastIndexOf(t.typeaheadBuffer,0)===0,u=!e(o.index);if(c&&u){s=l;break}l=(l+1)%a.length}return s!==-1?(t.sortedIndexCursor=s,a[t.sortedIndexCursor].index):-1}function Tn(i){return i.typeaheadBuffer.length>0}function On(i){i.typeaheadBuffer=""}function hn(i,e){var t=i.event,n=i.isTargetListItem,a=i.focusedItemIndex,r=i.focusItemAtIndex,l=i.sortedIndexByFirstChar,s=i.isItemAtIndexDisabled,o=_e(t)==="ArrowLeft",c=_e(t)==="ArrowUp",u=_e(t)==="ArrowRight",d=_e(t)==="ArrowDown",f=_e(t)==="Home",h=_e(t)==="End",g=_e(t)==="Enter",I=_e(t)==="Spacebar";if(t.altKey||t.ctrlKey||t.metaKey||o||c||u||d||f||h||g)return-1;var v=!I&&t.key.length===1;if(v){ke(t);var C={focusItemAtIndex:r,focusedItemIndex:a,nextChar:t.key.toLowerCase(),sortedIndexByFirstChar:l,skipFocus:!1,isItemAtIndexDisabled:s};return zt(C,e)}if(!I)return-1;n&&ke(t);var p=n&&Tn(e);if(p){var C={focusItemAtIndex:r,focusedItemIndex:a,nextChar:" ",sortedIndexByFirstChar:l,skipFocus:!1,isItemAtIndexDisabled:s};return zt(C,e)}return-1}/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */function fs(i){return i instanceof Array}var ms=["Alt","Control","Meta","Shift"];function pn(i){var e=new Set(i?ms.filter(function(t){return i.getModifierState(t)}):[]);return function(t){return t.every(function(n){return e.has(n)})&&t.length===e.size}}var hs=function(i){et(e,i);function e(t){var n=i.call(this,Ne(Ne({},e.defaultAdapter),t))||this;return n.wrapFocus=!1,n.isVertical=!0,n.isSingleSelectionList=!1,n.areDisabledItemsFocusable=!0,n.selectedIndex=ee.UNSET_INDEX,n.focusedItemIndex=ee.UNSET_INDEX,n.useActivatedClass=!1,n.useSelectedAttr=!1,n.ariaCurrentAttrValue=null,n.isCheckboxList=!1,n.isRadioList=!1,n.lastSelectedIndex=null,n.hasTypeahead=!1,n.typeaheadState=ls(),n.sortedIndexByFirstChar=new Map,n}return Object.defineProperty(e,"strings",{get:function(){return nt},enumerable:!1,configurable:!0}),Object.defineProperty(e,"cssClasses",{get:function(){return W},enumerable:!1,configurable:!0}),Object.defineProperty(e,"numbers",{get:function(){return ee},enumerable:!1,configurable:!0}),Object.defineProperty(e,"defaultAdapter",{get:function(){return{addClassForElementIndex:function(){},focusItemAtIndex:function(){},getAttributeForElementIndex:function(){return null},getFocusedElementIndex:function(){return 0},getListItemCount:function(){return 0},hasCheckboxAtIndex:function(){return!1},hasRadioAtIndex:function(){return!1},isCheckboxCheckedAtIndex:function(){return!1},isFocusInsideList:function(){return!1},isRootFocused:function(){return!1},listItemAtIndexHasClass:function(){return!1},notifyAction:function(){},notifySelectionChange:function(){},removeClassForElementIndex:function(){},setAttributeForElementIndex:function(){},setCheckedCheckboxOrRadioAtIndex:function(){},setTabIndexForListItemChildren:function(){},getPrimaryTextAtIndex:function(){return""}}},enumerable:!1,configurable:!0}),e.prototype.layout=function(){this.adapter.getListItemCount()!==0&&(this.adapter.hasCheckboxAtIndex(0)?this.isCheckboxList=!0:this.adapter.hasRadioAtIndex(0)?this.isRadioList=!0:this.maybeInitializeSingleSelection(),this.hasTypeahead&&(this.sortedIndexByFirstChar=this.typeaheadInitSortedIndex()))},e.prototype.getFocusedItemIndex=function(){return this.focusedItemIndex},e.prototype.setWrapFocus=function(t){this.wrapFocus=t},e.prototype.setVerticalOrientation=function(t){this.isVertical=t},e.prototype.setSingleSelection=function(t){this.isSingleSelectionList=t,t&&(this.maybeInitializeSingleSelection(),this.selectedIndex=this.getSelectedIndexFromDOM())},e.prototype.setDisabledItemsFocusable=function(t){this.areDisabledItemsFocusable=t},e.prototype.maybeInitializeSingleSelection=function(){var t=this.getSelectedIndexFromDOM();if(t!==ee.UNSET_INDEX){var n=this.adapter.listItemAtIndexHasClass(t,W.LIST_ITEM_ACTIVATED_CLASS);n&&this.setUseActivatedClass(!0),this.isSingleSelectionList=!0,this.selectedIndex=t}},e.prototype.getSelectedIndexFromDOM=function(){for(var t=ee.UNSET_INDEX,n=this.adapter.getListItemCount(),a=0;a<n;a++){var r=this.adapter.listItemAtIndexHasClass(a,W.LIST_ITEM_SELECTED_CLASS),l=this.adapter.listItemAtIndexHasClass(a,W.LIST_ITEM_ACTIVATED_CLASS);if(r||l){t=a;break}}return t},e.prototype.setHasTypeahead=function(t){this.hasTypeahead=t,t&&(this.sortedIndexByFirstChar=this.typeaheadInitSortedIndex())},e.prototype.isTypeaheadInProgress=function(){return this.hasTypeahead&&Tn(this.typeaheadState)},e.prototype.setUseActivatedClass=function(t){this.useActivatedClass=t},e.prototype.setUseSelectedAttribute=function(t){this.useSelectedAttr=t},e.prototype.getSelectedIndex=function(){return this.selectedIndex},e.prototype.setSelectedIndex=function(t,n){n===void 0&&(n={}),this.isIndexValid(t)&&(this.isCheckboxList?this.setCheckboxAtIndex(t,n):this.isRadioList?this.setRadioAtIndex(t,n):this.setSingleSelectionAtIndex(t,n))},e.prototype.handleFocusIn=function(t){t>=0&&(this.focusedItemIndex=t,this.adapter.setAttributeForElementIndex(t,"tabindex","0"),this.adapter.setTabIndexForListItemChildren(t,"0"))},e.prototype.handleFocusOut=function(t){var n=this;t>=0&&(this.adapter.setAttributeForElementIndex(t,"tabindex","-1"),this.adapter.setTabIndexForListItemChildren(t,"-1")),setTimeout(function(){n.adapter.isFocusInsideList()||n.setTabindexToFirstSelectedOrFocusedItem()},0)},e.prototype.isIndexDisabled=function(t){return this.adapter.listItemAtIndexHasClass(t,W.LIST_ITEM_DISABLED_CLASS)},e.prototype.handleKeydown=function(t,n,a){var r=this,l,s=_e(t)==="ArrowLeft",o=_e(t)==="ArrowUp",c=_e(t)==="ArrowRight",u=_e(t)==="ArrowDown",d=_e(t)==="Home",f=_e(t)==="End",h=_e(t)==="Enter",g=_e(t)==="Spacebar",I=this.isVertical&&u||!this.isVertical&&c,v=this.isVertical&&o||!this.isVertical&&s,C=t.key==="A"||t.key==="a",p=pn(t);if(this.adapter.isRootFocused()){if((v||f)&&p([]))t.preventDefault(),this.focusLastElement();else if((I||d)&&p([]))t.preventDefault(),this.focusFirstElement();else if(v&&p(["Shift"])&&this.isCheckboxList){t.preventDefault();var b=this.focusLastElement();b!==-1&&this.setSelectedIndexOnAction(b,!1)}else if(I&&p(["Shift"])&&this.isCheckboxList){t.preventDefault();var b=this.focusFirstElement();b!==-1&&this.setSelectedIndexOnAction(b,!1)}if(this.hasTypeahead){var R={event:t,focusItemAtIndex:function(j){r.focusItemAtIndex(j)},focusedItemIndex:-1,isTargetListItem:n,sortedIndexByFirstChar:this.sortedIndexByFirstChar,isItemAtIndexDisabled:function(j){return r.isIndexDisabled(j)}};hn(R,this.typeaheadState)}return}var S=this.adapter.getFocusedElementIndex();if(!(S===-1&&(S=a,S<0))){if(I&&p([]))ke(t),this.focusNextElement(S);else if(v&&p([]))ke(t),this.focusPrevElement(S);else if(I&&p(["Shift"])&&this.isCheckboxList){ke(t);var b=this.focusNextElement(S);b!==-1&&this.setSelectedIndexOnAction(b,!1)}else if(v&&p(["Shift"])&&this.isCheckboxList){ke(t);var b=this.focusPrevElement(S);b!==-1&&this.setSelectedIndexOnAction(b,!1)}else if(d&&p([]))ke(t),this.focusFirstElement();else if(f&&p([]))ke(t),this.focusLastElement();else if(d&&p(["Control","Shift"])&&this.isCheckboxList){if(ke(t),this.isIndexDisabled(S))return;this.focusFirstElement(),this.toggleCheckboxRange(0,S,S)}else if(f&&p(["Control","Shift"])&&this.isCheckboxList){if(ke(t),this.isIndexDisabled(S))return;this.focusLastElement(),this.toggleCheckboxRange(S,this.adapter.getListItemCount()-1,S)}else if(C&&p(["Control"])&&this.isCheckboxList)t.preventDefault(),this.checkboxListToggleAll(this.selectedIndex===ee.UNSET_INDEX?[]:this.selectedIndex,!0);else if((h||g)&&p([])){if(n){var k=t.target;if(k&&k.tagName==="A"&&h||(ke(t),this.isIndexDisabled(S)))return;this.isTypeaheadInProgress()||(this.isSelectableList()&&this.setSelectedIndexOnAction(S,!1),this.adapter.notifyAction(S))}}else if((h||g)&&p(["Shift"])&&this.isCheckboxList){var k=t.target;if(k&&k.tagName==="A"&&h||(ke(t),this.isIndexDisabled(S)))return;this.isTypeaheadInProgress()||(this.toggleCheckboxRange((l=this.lastSelectedIndex)!==null&&l!==void 0?l:S,S,S),this.adapter.notifyAction(S))}if(this.hasTypeahead){var R={event:t,focusItemAtIndex:function(J){r.focusItemAtIndex(J)},focusedItemIndex:this.focusedItemIndex,isTargetListItem:n,sortedIndexByFirstChar:this.sortedIndexByFirstChar,isItemAtIndexDisabled:function(J){return r.isIndexDisabled(J)}};hn(R,this.typeaheadState)}}},e.prototype.handleClick=function(t,n,a){var r,l=pn(a);t!==ee.UNSET_INDEX&&(this.isIndexDisabled(t)||(l([])?(this.isSelectableList()&&this.setSelectedIndexOnAction(t,n),this.adapter.notifyAction(t)):this.isCheckboxList&&l(["Shift"])&&(this.toggleCheckboxRange((r=this.lastSelectedIndex)!==null&&r!==void 0?r:t,t,t),this.adapter.notifyAction(t))))},e.prototype.focusNextElement=function(t){var n=this.adapter.getListItemCount(),a=t,r=null;do{if(a++,a>=n)if(this.wrapFocus)a=0;else return t;if(a===r)return-1;r=r??a}while(!this.areDisabledItemsFocusable&&this.isIndexDisabled(a));return this.focusItemAtIndex(a),a},e.prototype.focusPrevElement=function(t){var n=this.adapter.getListItemCount(),a=t,r=null;do{if(a--,a<0)if(this.wrapFocus)a=n-1;else return t;if(a===r)return-1;r=r??a}while(!this.areDisabledItemsFocusable&&this.isIndexDisabled(a));return this.focusItemAtIndex(a),a},e.prototype.focusFirstElement=function(){return this.focusNextElement(-1)},e.prototype.focusLastElement=function(){return this.focusPrevElement(this.adapter.getListItemCount())},e.prototype.focusInitialElement=function(){var t=this.getFirstSelectedOrFocusedItemIndex();return this.focusItemAtIndex(t),t},e.prototype.setEnabled=function(t,n){this.isIndexValid(t,!1)&&(n?(this.adapter.removeClassForElementIndex(t,W.LIST_ITEM_DISABLED_CLASS),this.adapter.setAttributeForElementIndex(t,nt.ARIA_DISABLED,"false")):(this.adapter.addClassForElementIndex(t,W.LIST_ITEM_DISABLED_CLASS),this.adapter.setAttributeForElementIndex(t,nt.ARIA_DISABLED,"true")))},e.prototype.setSingleSelectionAtIndex=function(t,n){if(n===void 0&&(n={}),!(this.selectedIndex===t&&!n.forceUpdate)){var a=W.LIST_ITEM_SELECTED_CLASS;this.useActivatedClass&&(a=W.LIST_ITEM_ACTIVATED_CLASS),this.selectedIndex!==ee.UNSET_INDEX&&this.adapter.removeClassForElementIndex(this.selectedIndex,a),this.setAriaForSingleSelectionAtIndex(t),this.setTabindexAtIndex(t),t!==ee.UNSET_INDEX&&this.adapter.addClassForElementIndex(t,a),this.selectedIndex=t,n.isUserInteraction&&!n.forceUpdate&&this.adapter.notifySelectionChange([t])}},e.prototype.setAriaForSingleSelectionAtIndex=function(t){this.selectedIndex===ee.UNSET_INDEX&&(this.ariaCurrentAttrValue=this.adapter.getAttributeForElementIndex(t,nt.ARIA_CURRENT));var n=this.ariaCurrentAttrValue!==null,a=n?nt.ARIA_CURRENT:nt.ARIA_SELECTED;if(this.selectedIndex!==ee.UNSET_INDEX&&this.adapter.setAttributeForElementIndex(this.selectedIndex,a,"false"),t!==ee.UNSET_INDEX){var r=n?this.ariaCurrentAttrValue:"true";this.adapter.setAttributeForElementIndex(t,a,r)}},e.prototype.getSelectionAttribute=function(){return this.useSelectedAttr?nt.ARIA_SELECTED:nt.ARIA_CHECKED},e.prototype.setRadioAtIndex=function(t,n){n===void 0&&(n={});var a=this.getSelectionAttribute();this.adapter.setCheckedCheckboxOrRadioAtIndex(t,!0),!(this.selectedIndex===t&&!n.forceUpdate)&&(this.selectedIndex!==ee.UNSET_INDEX&&this.adapter.setAttributeForElementIndex(this.selectedIndex,a,"false"),this.adapter.setAttributeForElementIndex(t,a,"true"),this.selectedIndex=t,n.isUserInteraction&&!n.forceUpdate&&this.adapter.notifySelectionChange([t]))},e.prototype.setCheckboxAtIndex=function(t,n){n===void 0&&(n={});for(var a=this.selectedIndex,r=n.isUserInteraction?new Set(a===ee.UNSET_INDEX?[]:a):null,l=this.getSelectionAttribute(),s=[],o=0;o<this.adapter.getListItemCount();o++){var c=r==null?void 0:r.has(o),u=t.indexOf(o)>=0;u!==c&&s.push(o),this.adapter.setCheckedCheckboxOrRadioAtIndex(o,u),this.adapter.setAttributeForElementIndex(o,l,u?"true":"false")}this.selectedIndex=t,n.isUserInteraction&&s.length&&this.adapter.notifySelectionChange(s)},e.prototype.toggleCheckboxRange=function(t,n,a){this.lastSelectedIndex=a;for(var r=new Set(this.selectedIndex===ee.UNSET_INDEX?[]:this.selectedIndex),l=!(r!=null&&r.has(a)),s=Yt([t,n].sort(),2),o=s[0],c=s[1],u=this.getSelectionAttribute(),d=[],f=o;f<=c;f++)if(!this.isIndexDisabled(f)){var h=r.has(f);l!==h&&(d.push(f),this.adapter.setCheckedCheckboxOrRadioAtIndex(f,l),this.adapter.setAttributeForElementIndex(f,u,""+l),l?r.add(f):r.delete(f))}d.length&&(this.selectedIndex=zn([],Yt(r)),this.adapter.notifySelectionChange(d))},e.prototype.setTabindexAtIndex=function(t){this.focusedItemIndex===ee.UNSET_INDEX&&t!==0?this.adapter.setAttributeForElementIndex(0,"tabindex","-1"):this.focusedItemIndex>=0&&this.focusedItemIndex!==t&&this.adapter.setAttributeForElementIndex(this.focusedItemIndex,"tabindex","-1"),!(this.selectedIndex instanceof Array)&&this.selectedIndex!==t&&this.adapter.setAttributeForElementIndex(this.selectedIndex,"tabindex","-1"),t!==ee.UNSET_INDEX&&this.adapter.setAttributeForElementIndex(t,"tabindex","0")},e.prototype.isSelectableList=function(){return this.isSingleSelectionList||this.isCheckboxList||this.isRadioList},e.prototype.setTabindexToFirstSelectedOrFocusedItem=function(){var t=this.getFirstSelectedOrFocusedItemIndex();this.setTabindexAtIndex(t)},e.prototype.getFirstSelectedOrFocusedItemIndex=function(){return this.isSelectableList()?typeof this.selectedIndex=="number"&&this.selectedIndex!==ee.UNSET_INDEX?this.selectedIndex:fs(this.selectedIndex)&&this.selectedIndex.length>0?this.selectedIndex.reduce(function(t,n){return Math.min(t,n)}):0:Math.max(this.focusedItemIndex,0)},e.prototype.isIndexValid=function(t,n){var a=this;if(n===void 0&&(n=!0),t instanceof Array){if(!this.isCheckboxList&&n)throw new Error("MDCListFoundation: Array of index is only supported for checkbox based list");return t.length===0?!0:t.some(function(r){return a.isIndexInRange(r)})}else if(typeof t=="number"){if(this.isCheckboxList&&n)throw new Error("MDCListFoundation: Expected array of index for checkbox based list but got number: "+t);return this.isIndexInRange(t)||this.isSingleSelectionList&&t===ee.UNSET_INDEX}else return!1},e.prototype.isIndexInRange=function(t){var n=this.adapter.getListItemCount();return t>=0&&t<n},e.prototype.setSelectedIndexOnAction=function(t,n){this.lastSelectedIndex=t,this.isCheckboxList?(this.toggleCheckboxAtIndex(t,n),this.adapter.notifySelectionChange([t])):this.setSelectedIndex(t,{isUserInteraction:!0})},e.prototype.toggleCheckboxAtIndex=function(t,n){var a=this.getSelectionAttribute(),r=this.adapter.isCheckboxCheckedAtIndex(t),l;n?l=r:(l=!r,this.adapter.setCheckedCheckboxOrRadioAtIndex(t,l)),this.adapter.setAttributeForElementIndex(t,a,l?"true":"false");var s=this.selectedIndex===ee.UNSET_INDEX?[]:this.selectedIndex.slice();l?s.push(t):s=s.filter(function(o){return o!==t}),this.selectedIndex=s},e.prototype.focusItemAtIndex=function(t){this.adapter.focusItemAtIndex(t),this.focusedItemIndex=t},e.prototype.checkboxListToggleAll=function(t,n){var a=this.adapter.getListItemCount();if(t.length===a)this.setCheckboxAtIndex([],{isUserInteraction:n});else{for(var r=[],l=0;l<a;l++)(!this.isIndexDisabled(l)||t.indexOf(l)>-1)&&r.push(l);this.setCheckboxAtIndex(r,{isUserInteraction:n})}},e.prototype.typeaheadMatchItem=function(t,n,a){var r=this;a===void 0&&(a=!1);var l={focusItemAtIndex:function(s){r.focusItemAtIndex(s)},focusedItemIndex:n||this.focusedItemIndex,nextChar:t,sortedIndexByFirstChar:this.sortedIndexByFirstChar,skipFocus:a,isItemAtIndexDisabled:function(s){return r.isIndexDisabled(s)}};return zt(l,this.typeaheadState)},e.prototype.typeaheadInitSortedIndex=function(){return us(this.adapter.getListItemCount(),this.adapter.getPrimaryTextAtIndex)},e.prototype.clearTypeaheadBuffer=function(){On(this.typeaheadState)},e}(En);/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Fe={ANIMATE:"mdc-drawer--animate",CLOSING:"mdc-drawer--closing",DISMISSIBLE:"mdc-drawer--dismissible",MODAL:"mdc-drawer--modal",OPEN:"mdc-drawer--open",OPENING:"mdc-drawer--opening",ROOT:"mdc-drawer"},ps={APP_CONTENT_SELECTOR:".mdc-drawer-app-content",CLOSE_EVENT:"MDCDrawer:closed",OPEN_EVENT:"MDCDrawer:opened",SCRIM_SELECTOR:".mdc-drawer-scrim",LIST_SELECTOR:".mdc-list,.mdc-deprecated-list",LIST_ITEM_ACTIVATED_SELECTOR:".mdc-list-item--activated,.mdc-deprecated-list-item--activated"};/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var Fn=function(i){et(e,i);function e(t){var n=i.call(this,Ne(Ne({},e.defaultAdapter),t))||this;return n.animationFrame=0,n.animationTimer=0,n}return Object.defineProperty(e,"strings",{get:function(){return ps},enumerable:!1,configurable:!0}),Object.defineProperty(e,"cssClasses",{get:function(){return Fe},enumerable:!1,configurable:!0}),Object.defineProperty(e,"defaultAdapter",{get:function(){return{addClass:function(){},removeClass:function(){},hasClass:function(){return!1},elementHasClass:function(){return!1},notifyClose:function(){},notifyOpen:function(){},saveFocus:function(){},restoreFocus:function(){},focusActiveNavigationItem:function(){},trapFocus:function(){},releaseFocus:function(){}}},enumerable:!1,configurable:!0}),e.prototype.destroy=function(){this.animationFrame&&cancelAnimationFrame(this.animationFrame),this.animationTimer&&clearTimeout(this.animationTimer)},e.prototype.open=function(){var t=this;this.isOpen()||this.isOpening()||this.isClosing()||(this.adapter.addClass(Fe.OPEN),this.adapter.addClass(Fe.ANIMATE),this.runNextAnimationFrame(function(){t.adapter.addClass(Fe.OPENING)}),this.adapter.saveFocus())},e.prototype.close=function(){!this.isOpen()||this.isOpening()||this.isClosing()||this.adapter.addClass(Fe.CLOSING)},e.prototype.isOpen=function(){return this.adapter.hasClass(Fe.OPEN)},e.prototype.isOpening=function(){return this.adapter.hasClass(Fe.OPENING)||this.adapter.hasClass(Fe.ANIMATE)},e.prototype.isClosing=function(){return this.adapter.hasClass(Fe.CLOSING)},e.prototype.handleKeydown=function(t){var n=t.keyCode,a=t.key,r=a==="Escape"||n===27;r&&this.close()},e.prototype.handleTransitionEnd=function(t){var n=Fe.OPENING,a=Fe.CLOSING,r=Fe.OPEN,l=Fe.ANIMATE,s=Fe.ROOT,o=this.isElement(t.target)&&this.adapter.elementHasClass(t.target,s);o&&(this.isClosing()?(this.adapter.removeClass(r),this.closed(),this.adapter.restoreFocus(),this.adapter.notifyClose()):(this.adapter.focusActiveNavigationItem(),this.opened(),this.adapter.notifyOpen()),this.adapter.removeClass(l),this.adapter.removeClass(n),this.adapter.removeClass(a))},e.prototype.opened=function(){},e.prototype.closed=function(){},e.prototype.runNextAnimationFrame=function(t){var n=this;cancelAnimationFrame(this.animationFrame),this.animationFrame=requestAnimationFrame(function(){n.animationFrame=0,clearTimeout(n.animationTimer),n.animationTimer=setTimeout(t,0)})},e.prototype.isElement=function(t){return Boolean(t.classList)},e}(En);/**
 * @license
 * Copyright 2018 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */var gs=function(i){et(e,i);function e(){return i!==null&&i.apply(this,arguments)||this}return e.prototype.handleScrimClick=function(){this.close()},e.prototype.opened=function(){this.adapter.trapFocus()},e.prototype.closed=function(){this.adapter.releaseFocus()},e}(Fn);function _s(i){let e,t,n,a,r,l;const s=i[15].default,o=ue(s,i,i[14],null);let c=[{class:t=ze({[i[1]]:!0,"mdc-drawer":!0,"mdc-drawer--dismissible":i[2]==="dismissible","mdc-drawer--modal":i[2]==="modal","smui-drawer__absolute":i[2]==="modal"&&!i[3],...i[6]})},i[8]],u={};for(let d=0;d<c.length;d+=1)u=B(u,c[d]);return{c(){e=ye("aside"),o&&o.c(),this.h()},l(d){e=Le(d,"ASIDE",{class:!0});var f=ce(e);o&&o.l(f),f.forEach(E),this.h()},h(){re(e,u)},m(d,f){M(d,e,f),o&&o.m(e,null),i[16](e),a=!0,r||(l=[ne(n=Vt.call(null,e,i[0])),ne(i[7].call(null,e)),$e(e,"keydown",function(){Be(i[4]&&i[4].handleKeydown.bind(i[4]))&&(i[4]&&i[4].handleKeydown.bind(i[4])).apply(this,arguments)}),$e(e,"transitionend",function(){Be(i[4]&&i[4].handleTransitionEnd.bind(i[4]))&&(i[4]&&i[4].handleTransitionEnd.bind(i[4])).apply(this,arguments)})],r=!0)},p(d,[f]){i=d,o&&o.p&&(!a||f&16384)&&de(o,s,i,i[14],a?me(s,i[14],f,null):fe(i[14]),null),re(e,u=Ae(c,[(!a||f&78&&t!==(t=ze({[i[1]]:!0,"mdc-drawer":!0,"mdc-drawer--dismissible":i[2]==="dismissible","mdc-drawer--modal":i[2]==="modal","smui-drawer__absolute":i[2]==="modal"&&!i[3],...i[6]})))&&{class:t},f&256&&i[8]])),n&&Be(n.update)&&f&1&&n.update.call(null,i[0])},i(d){a||(y(o,d),a=!0)},o(d){L(o,d),a=!1},d(d){d&&E(e),o&&o.d(d),i[16](null),r=!1,Ve(l)}}}function bs(i,e,t){const n=["use","class","variant","open","fixed","setOpen","isOpen","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e;const{FocusTrap:s}=as,o=pt(Ee());let{use:c=[]}=e,{class:u=""}=e,{variant:d=void 0}=e,{open:f=!1}=e,{fixed:h=!0}=e,g,I,v={},C=null,p,b=!1;pe("SMUI:list:nav",!0),pe("SMUI:list:item:nav",!0),pe("SMUI:list:wrapFocus",!0);let R=d;Bt(()=>{p=new s(g,{skipInitialFocus:!0}),t(4,I=S()),I&&I.init()}),At(()=>{I&&I.destroy(),b&&b.removeEventListener("SMUIDrawerScrim:click",$)});function S(){var T,z;b&&b.removeEventListener("SMUIDrawerScrim:click",$),d==="modal"&&(b=(z=(T=g.parentNode)===null||T===void 0?void 0:T.querySelector(".mdc-drawer-scrim"))!==null&&z!==void 0?z:!1,b&&b.addEventListener("SMUIDrawerScrim:click",$));const P=d==="dismissible"?Fn:d==="modal"?gs:void 0;return P?new P({addClass:j,removeClass:J,hasClass:k,elementHasClass:(Y,ie)=>Y.classList.contains(ie),saveFocus:()=>C=document.activeElement,restoreFocus:()=>{C&&"focus"in C&&g.contains(document.activeElement)&&C.focus()},focusActiveNavigationItem:()=>{const Y=g.querySelector(".mdc-list-item--activated,.mdc-deprecated-list-item--activated");Y&&Y.focus()},notifyClose:()=>{t(9,f=!1),st(g,"SMUIDrawer:closed",void 0,void 0,!0)},notifyOpen:()=>{t(9,f=!0),st(g,"SMUIDrawer:opened",void 0,void 0,!0)},trapFocus:()=>p.trapFocus(),releaseFocus:()=>p.releaseFocus()}):void 0}function k(T){return T in v?v[T]:Z().classList.contains(T)}function j(T){v[T]||t(6,v[T]=!0,v)}function J(T){(!(T in v)||v[T])&&t(6,v[T]=!1,v)}function $(){I&&"handleScrimClick"in I&&I.handleScrimClick()}function q(T){t(9,f=T)}function X(){return f}function Z(){return g}function Q(T){he[T?"unshift":"push"](()=>{g=T,t(5,g)})}return i.$$set=T=>{e=B(B({},e),Se(T)),t(8,a=K(e,n)),"use"in T&&t(0,c=T.use),"class"in T&&t(1,u=T.class),"variant"in T&&t(2,d=T.variant),"open"in T&&t(9,f=T.open),"fixed"in T&&t(3,h=T.fixed),"$$scope"in T&&t(14,l=T.$$scope)},i.$$.update=()=>{i.$$.dirty&8212&&R!==d&&(t(13,R=d),I&&I.destroy(),t(6,v={}),t(4,I=S()),I&&I.init()),i.$$.dirty&528&&I&&I.isOpen()!==f&&(f?I.open():I.close())},[c,u,d,h,I,g,v,o,a,f,q,X,Z,R,l,r,Q]}class Is extends ae{constructor(e){super(),oe(this,e,bs,_s,le,{use:0,class:1,variant:2,open:9,fixed:3,setOpen:10,isOpen:11,getElement:12})}get setOpen(){return this.$$.ctx[10]}get isOpen(){return this.$$.ctx[11]}get getElement(){return this.$$.ctx[12]}}He({class:"mdc-drawer-app-content",tag:"div"});const As=He({class:"mdc-drawer__content",tag:"div"});He({class:"mdc-drawer__header",tag:"div"});He({class:"mdc-drawer__title",tag:"h1"});He({class:"mdc-drawer__subtitle",tag:"h2"});function Es(i){let e;const t=i[41].default,n=ue(t,i,i[43],null);return{c(){n&&n.c()},l(a){n&&n.l(a)},m(a,r){n&&n.m(a,r),e=!0},p(a,r){n&&n.p&&(!e||r[1]&4096)&&de(n,t,a,a[43],e?me(t,a[43],r,null):fe(a[43]),null)},i(a){e||(y(n,a),e=!0)},o(a){L(n,a),e=!1},d(a){n&&n.d(a)}}}function Ss(i){let e,t,n;const a=[{tag:i[13]},{use:[i[16],...i[0]]},{class:ze({[i[1]]:!0,"mdc-deprecated-list":!0,"mdc-deprecated-list--non-interactive":i[2],"mdc-deprecated-list--dense":i[3],"mdc-deprecated-list--textual-list":i[4],"mdc-deprecated-list--avatar-list":i[5]||i[17],"mdc-deprecated-list--icon-list":i[6],"mdc-deprecated-list--image-list":i[7],"mdc-deprecated-list--thumbnail-list":i[8],"mdc-deprecated-list--video-list":i[9],"mdc-deprecated-list--two-line":i[10],"smui-list--three-line":i[11]&&!i[10]})},{role:i[15]},i[25]];var r=i[12];function l(s){let o={$$slots:{default:[Es]},$$scope:{ctx:s}};for(let c=0;c<a.length;c+=1)o=B(o,a[c]);return{props:o}}return r&&(e=Pe(r,l(i)),i[42](e),e.$on("keydown",i[20]),e.$on("focusin",i[21]),e.$on("focusout",i[22]),e.$on("click",i[23]),e.$on("SMUIListItem:mount",i[18]),e.$on("SMUIListItem:unmount",i[19]),e.$on("SMUI:action",i[24])),{c(){e&&w(e.$$.fragment),t=Ie()},l(s){e&&V(e.$$.fragment,s),t=Ie()},m(s,o){e&&N(e,s,o),M(s,t,o),n=!0},p(s,o){const c=o[0]&33796095?Ae(a,[o[0]&8192&&{tag:s[13]},o[0]&65537&&{use:[s[16],...s[0]]},o[0]&135166&&{class:ze({[s[1]]:!0,"mdc-deprecated-list":!0,"mdc-deprecated-list--non-interactive":s[2],"mdc-deprecated-list--dense":s[3],"mdc-deprecated-list--textual-list":s[4],"mdc-deprecated-list--avatar-list":s[5]||s[17],"mdc-deprecated-list--icon-list":s[6],"mdc-deprecated-list--image-list":s[7],"mdc-deprecated-list--thumbnail-list":s[8],"mdc-deprecated-list--video-list":s[9],"mdc-deprecated-list--two-line":s[10],"smui-list--three-line":s[11]&&!s[10]})},o[0]&32768&&{role:s[15]},o[0]&33554432&&be(s[25])]):{};if(o[1]&4096&&(c.$$scope={dirty:o,ctx:s}),r!==(r=s[12])){if(e){ht();const u=e;L(u.$$.fragment,1,0,()=>{H(u,1)}),mt()}r?(e=Pe(r,l(s)),s[42](e),e.$on("keydown",s[20]),e.$on("focusin",s[21]),e.$on("focusout",s[22]),e.$on("click",s[23]),e.$on("SMUIListItem:mount",s[18]),e.$on("SMUIListItem:unmount",s[19]),e.$on("SMUI:action",s[24]),w(e.$$.fragment),y(e.$$.fragment,1),N(e,t.parentNode,t)):e=null}else r&&e.$set(c)},i(s){n||(e&&y(e.$$.fragment,s),n=!0)},o(s){e&&L(e.$$.fragment,s),n=!1},d(s){i[42](null),s&&E(t),e&&H(e,s)}}}function vs(i,e,t){const n=["use","class","nonInteractive","dense","textualList","avatarList","iconList","imageList","thumbnailList","videoList","twoLine","threeLine","vertical","wrapFocus","singleSelection","disabledItemsFocusable","selectedIndex","radioList","checkList","hasTypeahead","component","tag","layout","setEnabled","getTypeaheadInProgress","getSelectedIndex","getFocusedItemIndex","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e;var s;const{closest:o,matches:c}=Vn,u=pt(Ee());let{use:d=[]}=e,{class:f=""}=e,{nonInteractive:h=!1}=e,{dense:g=!1}=e,{textualList:I=!1}=e,{avatarList:v=!1}=e,{iconList:C=!1}=e,{imageList:p=!1}=e,{thumbnailList:b=!1}=e,{videoList:R=!1}=e,{twoLine:S=!1}=e,{threeLine:k=!1}=e,{vertical:j=!0}=e,{wrapFocus:J=(s=De("SMUI:list:wrapFocus"))!==null&&s!==void 0?s:!1}=e,{singleSelection:$=!1}=e,{disabledItemsFocusable:q=!1}=e,{selectedIndex:X=-1}=e,{radioList:Z=!1}=e,{checkList:Q=!1}=e,{hasTypeahead:T=!1}=e,z,P,Y=[],ie=De("SMUI:list:role"),Ke=De("SMUI:list:nav");const je=new WeakMap;let qe=De("SMUI:dialog:selection"),Ze=De("SMUI:addLayoutListener"),Je,{component:F=ft}=e,{tag:Ue=F===ft?Ke?"nav":"ul":void 0}=e;pe("SMUI:list:nonInteractive",h),pe("SMUI:separator:context","list"),ie||($?(ie="listbox",pe("SMUI:list:item:role","option")):Z?(ie="radiogroup",pe("SMUI:list:item:role","radio")):Q?(ie="group",pe("SMUI:list:item:role","checkbox")):(ie="list",pe("SMUI:list:item:role",void 0))),Ze&&(Je=Ze(Zt)),Bt(()=>{t(40,P=new hs({addClassForElementIndex:U,focusItemAtIndex:St,getAttributeForElementIndex:(D,O)=>{var x,It;return(It=(x=te()[D])===null||x===void 0?void 0:x.getAttr(O))!==null&&It!==void 0?It:null},getFocusedElementIndex:()=>document.activeElement?te().map(D=>D.element).indexOf(document.activeElement):-1,getListItemCount:()=>Y.length,getPrimaryTextAtIndex:qt,hasCheckboxAtIndex:D=>{var O,x;return(x=(O=te()[D])===null||O===void 0?void 0:O.hasCheckbox)!==null&&x!==void 0?x:!1},hasRadioAtIndex:D=>{var O,x;return(x=(O=te()[D])===null||O===void 0?void 0:O.hasRadio)!==null&&x!==void 0?x:!1},isCheckboxCheckedAtIndex:D=>{var O;const x=te()[D];return(O=(x==null?void 0:x.hasCheckbox)&&x.checked)!==null&&O!==void 0?O:!1},isFocusInsideList:()=>z!=null&&Qe()!==document.activeElement&&Qe().contains(document.activeElement),isRootFocused:()=>z!=null&&document.activeElement===Qe(),listItemAtIndexHasClass:_,notifyAction:D=>{t(26,X=D),z!=null&&st(Qe(),"SMUIList:action",{index:D},void 0,!0)},notifySelectionChange:D=>{z!=null&&st(Qe(),"SMUIList:selectionChange",{changedIndices:D})},removeClassForElementIndex:se,setAttributeForElementIndex:ut,setCheckedCheckboxOrRadioAtIndex:(D,O)=>{te()[D].checked=O},setTabIndexForListItemChildren:(D,O)=>{const x=te()[D],It="button:not(:disabled), a";Array.prototype.forEach.call(x.element.querySelectorAll(It),Bn=>{Bn.setAttribute("tabindex",O)})}}));const m={get element(){return Qe()},get items(){return Y},get typeaheadInProgress(){return P.isTypeaheadInProgress()},typeaheadMatchItem(D,O){return P.typeaheadMatchItem(D,O,!0)},getOrderedList:te,focusItemAtIndex:St,addClassForElementIndex:U,removeClassForElementIndex:se,setAttributeForElementIndex:ut,removeAttributeForElementIndex:vt,getAttributeFromElementIndex:Ct,getPrimaryTextAtIndex:qt};return st(Qe(),"SMUIList:mount",m),P.init(),P.layout(),()=>{P.destroy()}}),At(()=>{Je&&Je()});function we(m){Y.push(m.detail),je.set(m.detail.element,m.detail),$&&m.detail.selected&&t(26,X=ct(m.detail.element)),m.stopPropagation()}function gt(m){var D;const O=(D=m.detail&&Y.indexOf(m.detail))!==null&&D!==void 0?D:-1;O!==-1&&(Y.splice(O,1),Y=Y,je.delete(m.detail.element)),m.stopPropagation()}function _t(m){P&&m.target&&P.handleKeydown(m,m.target.classList.contains("mdc-deprecated-list-item"),ct(m.target))}function bt(m){P&&m.target&&P.handleFocusIn(ct(m.target))}function A(m){P&&m.target&&P.handleFocusOut(ct(m.target))}function ge(m){P&&m.target&&P.handleClick(ct(m.target),!c(m.target,'input[type="checkbox"], input[type="radio"]'),m)}function Ge(m){if(Z||Q){const D=ct(m.target);if(D!==-1){const O=te()[D];O&&(Z&&!O.checked||Q)&&(c(m.detail.target,'input[type="checkbox"], input[type="radio"]')||(O.checked=!O.checked),O.activateRipple(),window.requestAnimationFrame(()=>{O.deactivateRipple()}))}}}function te(){return z==null?[]:[...Qe().children].map(m=>je.get(m)).filter(m=>m&&m._smui_list_item_accessor)}function St(m){const D=te()[m];D&&"focus"in D.element&&D.element.focus()}function _(m,D){var O;const x=te()[m];return(O=x&&x.hasClass(D))!==null&&O!==void 0?O:!1}function U(m,D){const O=te()[m];O&&O.addClass(D)}function se(m,D){const O=te()[m];O&&O.removeClass(D)}function ut(m,D,O){const x=te()[m];x&&x.addAttr(D,O)}function vt(m,D){const O=te()[m];O&&O.removeAttr(D)}function Ct(m,D){const O=te()[m];return O?O.getAttr(D):null}function qt(m){var D;const O=te()[m];return(D=O&&O.getPrimaryText())!==null&&D!==void 0?D:""}function ct(m){const D=o(m,".mdc-deprecated-list-item, .mdc-deprecated-list");return D&&c(D,".mdc-deprecated-list-item")?te().map(O=>O==null?void 0:O.element).indexOf(D):-1}function Zt(){return P.layout()}function Dn(m,D){return P.setEnabled(m,D)}function Rn(){return P.isTypeaheadInProgress()}function Jt(){return P.getSelectedIndex()}function Mn(){return P.getFocusedItemIndex()}function Qe(){return z.getElement()}function kn(m){he[m?"unshift":"push"](()=>{z=m,t(14,z)})}return i.$$set=m=>{e=B(B({},e),Se(m)),t(25,a=K(e,n)),"use"in m&&t(0,d=m.use),"class"in m&&t(1,f=m.class),"nonInteractive"in m&&t(2,h=m.nonInteractive),"dense"in m&&t(3,g=m.dense),"textualList"in m&&t(4,I=m.textualList),"avatarList"in m&&t(5,v=m.avatarList),"iconList"in m&&t(6,C=m.iconList),"imageList"in m&&t(7,p=m.imageList),"thumbnailList"in m&&t(8,b=m.thumbnailList),"videoList"in m&&t(9,R=m.videoList),"twoLine"in m&&t(10,S=m.twoLine),"threeLine"in m&&t(11,k=m.threeLine),"vertical"in m&&t(27,j=m.vertical),"wrapFocus"in m&&t(28,J=m.wrapFocus),"singleSelection"in m&&t(29,$=m.singleSelection),"disabledItemsFocusable"in m&&t(30,q=m.disabledItemsFocusable),"selectedIndex"in m&&t(26,X=m.selectedIndex),"radioList"in m&&t(31,Z=m.radioList),"checkList"in m&&t(32,Q=m.checkList),"hasTypeahead"in m&&t(33,T=m.hasTypeahead),"component"in m&&t(12,F=m.component),"tag"in m&&t(13,Ue=m.tag),"$$scope"in m&&t(43,l=m.$$scope)},i.$$.update=()=>{i.$$.dirty[0]&134217728|i.$$.dirty[1]&512&&P&&P.setVerticalOrientation(j),i.$$.dirty[0]&268435456|i.$$.dirty[1]&512&&P&&P.setWrapFocus(J),i.$$.dirty[1]&516&&P&&P.setHasTypeahead(T),i.$$.dirty[0]&536870912|i.$$.dirty[1]&512&&P&&P.setSingleSelection($),i.$$.dirty[0]&1073741824|i.$$.dirty[1]&512&&P&&P.setDisabledItemsFocusable(q),i.$$.dirty[0]&603979776|i.$$.dirty[1]&512&&P&&$&&Jt()!==X&&P.setSelectedIndex(X)},[d,f,h,g,I,v,C,p,b,R,S,k,F,Ue,z,ie,u,qe,we,gt,_t,bt,A,ge,Ge,a,X,j,J,$,q,Z,Q,T,Zt,Dn,Rn,Jt,Mn,Qe,P,r,kn,l]}class Cs extends ae{constructor(e){super(),oe(this,e,vs,Ss,le,{use:0,class:1,nonInteractive:2,dense:3,textualList:4,avatarList:5,iconList:6,imageList:7,thumbnailList:8,videoList:9,twoLine:10,threeLine:11,vertical:27,wrapFocus:28,singleSelection:29,disabledItemsFocusable:30,selectedIndex:26,radioList:31,checkList:32,hasTypeahead:33,component:12,tag:13,layout:34,setEnabled:35,getTypeaheadInProgress:36,getSelectedIndex:37,getFocusedItemIndex:38,getElement:39},null,[-1,-1])}get layout(){return this.$$.ctx[34]}get setEnabled(){return this.$$.ctx[35]}get getTypeaheadInProgress(){return this.$$.ctx[36]}get getSelectedIndex(){return this.$$.ctx[37]}get getFocusedItemIndex(){return this.$$.ctx[38]}get getElement(){return this.$$.ctx[39]}}function gn(i){let e;return{c(){e=ye("span"),this.h()},l(t){e=Le(t,"SPAN",{class:!0}),ce(e).forEach(E),this.h()},h(){Me(e,"class","mdc-deprecated-list-item__ripple")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function ys(i){let e,t,n=i[7]&&gn();const a=i[34].default,r=ue(a,i,i[37],null);return{c(){n&&n.c(),e=Ie(),r&&r.c()},l(l){n&&n.l(l),e=Ie(),r&&r.l(l)},m(l,s){n&&n.m(l,s),M(l,e,s),r&&r.m(l,s),t=!0},p(l,s){l[7]?n||(n=gn(),n.c(),n.m(e.parentNode,e)):n&&(n.d(1),n=null),r&&r.p&&(!t||s[1]&64)&&de(r,a,l,l[37],t?me(a,l[37],s,null):fe(l[37]),null)},i(l){t||(y(r,l),t=!0)},o(l){L(r,l),t=!1},d(l){n&&n.d(l),l&&E(e),r&&r.d(l)}}}function Ls(i){let e,t,n;const a=[{tag:i[14]},{use:[...i[6]?[]:[[xt,{ripple:!i[16],unbounded:!1,color:(i[1]||i[0])&&i[5]==null?"primary":i[5],disabled:i[10],addClass:i[24],removeClass:i[25],addStyle:i[26]}]],i[22],...i[2]]},{class:ze({[i[3]]:!0,"mdc-deprecated-list-item":!i[8],"mdc-deprecated-list-item__wrapper":i[8],"mdc-deprecated-list-item--activated":i[1],"mdc-deprecated-list-item--selected":i[0],"mdc-deprecated-list-item--disabled":i[10],"mdc-menu-item--selected":!i[23]&&i[9]==="menuitem"&&i[0],"smui-menu-item--non-interactive":i[6],...i[18]})},{style:Object.entries(i[19]).map(_n).concat([i[4]]).join(" ")},i[23]&&i[1]?{"aria-current":"page"}:{},!i[23]||i[8]?{role:i[9]}:{},!i[23]&&i[9]==="option"?{"aria-selected":i[0]?"true":"false"}:{},!i[23]&&(i[9]==="radio"||i[9]==="checkbox")?{"aria-checked":i[16]&&i[16].checked?"true":"false"}:{},i[23]?{}:{"aria-disabled":i[10]?"true":"false"},{"data-menu-item-skip-restore-focus":i[11]||void 0},{tabindex:i[21]},{href:i[12]},i[20],i[29]];var r=i[13];function l(s){let o={$$slots:{default:[ys]},$$scope:{ctx:s}};for(let c=0;c<a.length;c+=1)o=B(o,a[c]);return{props:o}}return r&&(e=Pe(r,l(i)),i[35](e),e.$on("click",i[15]),e.$on("keydown",i[27]),e.$on("SMUIGenericInput:mount",i[28]),e.$on("SMUIGenericInput:unmount",i[36])),{c(){e&&w(e.$$.fragment),t=Ie()},l(s){e&&V(e.$$.fragment,s),t=Ie()},m(s,o){e&&N(e,s,o),M(s,t,o),n=!0},p(s,o){const c=o[0]&670916479?Ae(a,[o[0]&16384&&{tag:s[14]},o[0]&121701479&&{use:[...s[6]?[]:[[xt,{ripple:!s[16],unbounded:!1,color:(s[1]||s[0])&&s[5]==null?"primary":s[5],disabled:s[10],addClass:s[24],removeClass:s[25],addStyle:s[26]}]],s[22],...s[2]]},o[0]&8652619&&{class:ze({[s[3]]:!0,"mdc-deprecated-list-item":!s[8],"mdc-deprecated-list-item__wrapper":s[8],"mdc-deprecated-list-item--activated":s[1],"mdc-deprecated-list-item--selected":s[0],"mdc-deprecated-list-item--disabled":s[10],"mdc-menu-item--selected":!s[23]&&s[9]==="menuitem"&&s[0],"smui-menu-item--non-interactive":s[6],...s[18]})},o[0]&524304&&{style:Object.entries(s[19]).map(_n).concat([s[4]]).join(" ")},o[0]&8388610&&be(s[23]&&s[1]?{"aria-current":"page"}:{}),o[0]&8389376&&be(!s[23]||s[8]?{role:s[9]}:{}),o[0]&8389121&&be(!s[23]&&s[9]==="option"?{"aria-selected":s[0]?"true":"false"}:{}),o[0]&8454656&&be(!s[23]&&(s[9]==="radio"||s[9]==="checkbox")?{"aria-checked":s[16]&&s[16].checked?"true":"false"}:{}),o[0]&8389632&&be(s[23]?{}:{"aria-disabled":s[10]?"true":"false"}),o[0]&2048&&{"data-menu-item-skip-restore-focus":s[11]||void 0},o[0]&2097152&&{tabindex:s[21]},o[0]&4096&&{href:s[12]},o[0]&1048576&&be(s[20]),o[0]&536870912&&be(s[29])]):{};if(o[0]&128|o[1]&64&&(c.$$scope={dirty:o,ctx:s}),r!==(r=s[13])){if(e){ht();const u=e;L(u.$$.fragment,1,0,()=>{H(u,1)}),mt()}r?(e=Pe(r,l(s)),s[35](e),e.$on("click",s[15]),e.$on("keydown",s[27]),e.$on("SMUIGenericInput:mount",s[28]),e.$on("SMUIGenericInput:unmount",s[36]),w(e.$$.fragment),y(e.$$.fragment,1),N(e,t.parentNode,t)):e=null}else r&&e.$set(c)},i(s){n||(e&&y(e.$$.fragment,s),n=!0)},o(s){e&&L(e.$$.fragment,s),n=!1},d(s){i[35](null),s&&E(t),e&&H(e,s)}}}let Ts=0;const _n=([i,e])=>`${i}: ${e};`;function Os(i,e,t){let n;const a=["use","class","style","color","nonInteractive","ripple","wrapper","activated","role","selected","disabled","skipRestoreFocus","tabindex","inputId","href","component","tag","action","getPrimaryText","getElement"];let r=K(e,a),{$$slots:l={},$$scope:s}=e;var o;const c=pt(Ee());let u=()=>{};function d(_){return _===u}let{use:f=[]}=e,{class:h=""}=e,{style:g=""}=e,{color:I=void 0}=e,{nonInteractive:v=(o=De("SMUI:list:nonInteractive"))!==null&&o!==void 0?o:!1}=e;pe("SMUI:list:nonInteractive",void 0);let{ripple:C=!v}=e,{wrapper:p=!1}=e,{activated:b=!1}=e,{role:R=p?"presentation":De("SMUI:list:item:role")}=e;pe("SMUI:list:item:role",void 0);let{selected:S=!1}=e,{disabled:k=!1}=e,{skipRestoreFocus:j=!1}=e,{tabindex:J=u}=e,{inputId:$="SMUI-form-field-list-"+Ts++}=e,{href:q=void 0}=e,X,Z={},Q={},T={},z,P,Y=De("SMUI:list:item:nav"),{component:ie=ft}=e,{tag:Ke=ie===ft?Y?q?"a":"span":"li":void 0}=e;pe("SMUI:generic:input:props",{id:$}),pe("SMUI:separator:context",void 0),Bt(()=>{if(!S&&!v){let U=!0,se=X;for(;se.previousSibling;)if(se=se.previousSibling,se.nodeType===1&&se.classList.contains("mdc-deprecated-list-item")&&!se.classList.contains("mdc-deprecated-list-item--disabled")){U=!1;break}U&&(P=window.requestAnimationFrame(gt))}const _={_smui_list_item_accessor:!0,get element(){return Ge()},get selected(){return S},set selected(U){t(0,S=U)},hasClass:je,addClass:qe,removeClass:Ze,getAttr:F,addAttr:Ue,removeAttr:we,getPrimaryText:ge,get checked(){var U;return(U=z&&z.checked)!==null&&U!==void 0?U:!1},set checked(U){z&&t(16,z.checked=!!U,z)},get hasCheckbox(){return!!(z&&"_smui_checkbox_accessor"in z)},get hasRadio(){return!!(z&&"_smui_radio_accessor"in z)},activateRipple(){z&&z.activateRipple()},deactivateRipple(){z&&z.deactivateRipple()},getValue(){return r.value},action:A,get tabindex(){return n},set tabindex(U){t(30,J=U)},get disabled(){return k},get activated(){return b},set activated(U){t(1,b=U)}};return st(Ge(),"SMUIListItem:mount",_),()=>{st(Ge(),"SMUIListItem:unmount",_)}}),At(()=>{P&&window.cancelAnimationFrame(P)});function je(_){return _ in Z?Z[_]:Ge().classList.contains(_)}function qe(_){Z[_]||t(18,Z[_]=!0,Z)}function Ze(_){(!(_ in Z)||Z[_])&&t(18,Z[_]=!1,Z)}function Je(_,U){Q[_]!=U&&(U===""||U==null?(delete Q[_],t(19,Q)):t(19,Q[_]=U,Q))}function F(_){var U;return _ in T?(U=T[_])!==null&&U!==void 0?U:null:Ge().getAttribute(_)}function Ue(_,U){T[_]!==U&&t(20,T[_]=U,T)}function we(_){(!(_ in T)||T[_]!=null)&&t(20,T[_]=void 0,T)}function gt(){let _=!0,U=X.getElement();for(;U.nextElementSibling;)if(U=U.nextElementSibling,U.nodeType===1&&U.classList.contains("mdc-deprecated-list-item")){const se=U.attributes.getNamedItem("tabindex");if(se&&se.value==="0"){_=!1;break}}_&&t(21,n=0)}function _t(_){const U=_.key==="Enter",se=_.key==="Space";(U||se)&&A(_)}function bt(_){("_smui_checkbox_accessor"in _.detail||"_smui_radio_accessor"in _.detail)&&t(16,z=_.detail)}function A(_){k||st(Ge(),"SMUI:action",_)}function ge(){var _,U,se;const ut=Ge(),vt=ut.querySelector(".mdc-deprecated-list-item__primary-text");if(vt)return(_=vt.textContent)!==null&&_!==void 0?_:"";const Ct=ut.querySelector(".mdc-deprecated-list-item__text");return Ct?(U=Ct.textContent)!==null&&U!==void 0?U:"":(se=ut.textContent)!==null&&se!==void 0?se:""}function Ge(){return X.getElement()}function te(_){he[_?"unshift":"push"](()=>{X=_,t(17,X)})}const St=()=>t(16,z=void 0);return i.$$set=_=>{e=B(B({},e),Se(_)),t(29,r=K(e,a)),"use"in _&&t(2,f=_.use),"class"in _&&t(3,h=_.class),"style"in _&&t(4,g=_.style),"color"in _&&t(5,I=_.color),"nonInteractive"in _&&t(6,v=_.nonInteractive),"ripple"in _&&t(7,C=_.ripple),"wrapper"in _&&t(8,p=_.wrapper),"activated"in _&&t(1,b=_.activated),"role"in _&&t(9,R=_.role),"selected"in _&&t(0,S=_.selected),"disabled"in _&&t(10,k=_.disabled),"skipRestoreFocus"in _&&t(11,j=_.skipRestoreFocus),"tabindex"in _&&t(30,J=_.tabindex),"inputId"in _&&t(31,$=_.inputId),"href"in _&&t(12,q=_.href),"component"in _&&t(13,ie=_.component),"tag"in _&&t(14,Ke=_.tag),"$$scope"in _&&t(37,s=_.$$scope)},i.$$.update=()=>{i.$$.dirty[0]&1073808449&&t(21,n=d(J)?!v&&!k&&(S||z&&z.checked)?0:-1:J)},[S,b,f,h,g,I,v,C,p,R,k,j,q,ie,Ke,A,z,X,Z,Q,T,n,c,Y,qe,Ze,Je,_t,bt,r,J,$,ge,Ge,l,te,St,s]}class Rt extends ae{constructor(e){super(),oe(this,e,Os,Ls,le,{use:2,class:3,style:4,color:5,nonInteractive:6,ripple:7,wrapper:8,activated:1,role:9,selected:0,disabled:10,skipRestoreFocus:11,tabindex:30,inputId:31,href:12,component:13,tag:14,action:15,getPrimaryText:32,getElement:33},null,[-1,-1])}get action(){return this.$$.ctx[15]}get getPrimaryText(){return this.$$.ctx[32]}get getElement(){return this.$$.ctx[33]}}const Ht=He({class:"mdc-deprecated-list-item__text",tag:"span"});He({class:"mdc-deprecated-list-item__primary-text",tag:"span"});He({class:"mdc-deprecated-list-item__secondary-text",tag:"span"});function Fs(i){let e,t,n,a,r,l;const s=i[8].default,o=ue(s,i,i[7],null);let c=[{class:t=ze({[i[1]]:!0,"mdc-deprecated-list-item__graphic":!0,"mdc-menu__selection-group-icon":i[4]})},i[5]],u={};for(let d=0;d<c.length;d+=1)u=B(u,c[d]);return{c(){e=ye("span"),o&&o.c(),this.h()},l(d){e=Le(d,"SPAN",{class:!0});var f=ce(e);o&&o.l(f),f.forEach(E),this.h()},h(){re(e,u)},m(d,f){M(d,e,f),o&&o.m(e,null),i[9](e),a=!0,r||(l=[ne(n=Vt.call(null,e,i[0])),ne(i[3].call(null,e))],r=!0)},p(d,[f]){o&&o.p&&(!a||f&128)&&de(o,s,d,d[7],a?me(s,d[7],f,null):fe(d[7]),null),re(e,u=Ae(c,[(!a||f&2&&t!==(t=ze({[d[1]]:!0,"mdc-deprecated-list-item__graphic":!0,"mdc-menu__selection-group-icon":d[4]})))&&{class:t},f&32&&d[5]])),n&&Be(n.update)&&f&1&&n.update.call(null,d[0])},i(d){a||(y(o,d),a=!0)},o(d){L(o,d),a=!1},d(d){d&&E(e),o&&o.d(d),i[9](null),r=!1,Ve(l)}}}function Ds(i,e,t){const n=["use","class","getElement"];let a=K(e,n),{$$slots:r={},$$scope:l}=e;const s=pt(Ee());let{use:o=[]}=e,{class:c=""}=e,u,d=De("SMUI:list:graphic:menu-selection-group");function f(){return u}function h(g){he[g?"unshift":"push"](()=>{u=g,t(2,u)})}return i.$$set=g=>{e=B(B({},e),Se(g)),t(5,a=K(e,n)),"use"in g&&t(0,o=g.use),"class"in g&&t(1,c=g.class),"$$scope"in g&&t(7,l=g.$$scope)},[o,c,u,s,d,a,f,l,r,h]}class jt extends ae{constructor(e){super(),oe(this,e,Ds,Fs,le,{use:0,class:1,getElement:6})}get getElement(){return this.$$.ctx[6]}}He({class:"mdc-deprecated-list-item__meta",tag:"span"});He({class:"mdc-deprecated-list-group",tag:"div"});He({class:"mdc-deprecated-list-group__subheader",tag:"h3"});function Rs(i){let e;return{c(){e=We("menu")},l(t){e=Xe(t,"menu")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function Ms(i){let e;return{c(){e=We("SoundbridgeFx")},l(t){e=Xe(t,"SoundbridgeFx")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function ks(i){let e,t,n,a;return e=new kt({props:{class:"material-icons",$$slots:{default:[Rs]},$$scope:{ctx:i}}}),e.$on("click",i[6]),n=new bi({props:{$$slots:{default:[Ms]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment)},l(r){V(e.$$.fragment,r),t=Ce(r),V(n.$$.fragment,r)},m(r,l){N(e,r,l),M(r,t,l),N(n,r,l),a=!0},p(r,l){const s={};l&8192&&(s.$$scope={dirty:l,ctx:r}),e.$set(s);const o={};l&8192&&(o.$$scope={dirty:l,ctx:r}),n.$set(o)},i(r){a||(y(e.$$.fragment,r),y(n.$$.fragment,r),a=!0)},o(r){L(e.$$.fragment,r),L(n.$$.fragment,r),a=!1},d(r){H(e,r),r&&E(t),H(n,r)}}}function Bs(i){let e;return{c(){e=Ut("path"),this.h()},l(t){e=wt(t,"path",{fill:!0,d:!0}),ce(e).forEach(E),this.h()},h(){Me(e,"fill","currentColor"),Me(e,"d",ns)},m(t,n){M(t,e,n)},p:Pt,d(t){t&&E(e)}}}function Ps(i){let e,t;return e=new Kt({props:{component:Nt,viewBox:"0 0 24 24",$$slots:{default:[Bs]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment)},l(n){V(e.$$.fragment,n)},m(n,a){N(e,n,a),t=!0},p(n,a){const r={};a&8192&&(r.$$scope={dirty:a,ctx:n}),e.$set(r)},i(n){t||(y(e.$$.fragment,n),t=!0)},o(n){L(e.$$.fragment,n),t=!1},d(n){H(e,n)}}}function Us(i){let e;return{c(){e=Ut("path"),this.h()},l(t){e=wt(t,"path",{fill:!0,d:!0}),ce(e).forEach(E),this.h()},h(){Me(e,"fill","currentColor"),Me(e,"d",ss)},m(t,n){M(t,e,n)},p:Pt,d(t){t&&E(e)}}}function ws(i){let e,t;return e=new Kt({props:{component:Nt,viewBox:"0 0 24 24",$$slots:{default:[Us]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment)},l(n){V(e.$$.fragment,n)},m(n,a){N(e,n,a),t=!0},p(n,a){const r={};a&8192&&(r.$$scope={dirty:a,ctx:n}),e.$set(r)},i(n){t||(y(e.$$.fragment,n),t=!0)},o(n){L(e.$$.fragment,n),t=!1},d(n){H(e,n)}}}function Ns(i){let e;return{c(){e=Ut("path"),this.h()},l(t){e=wt(t,"path",{fill:!0,d:!0}),ce(e).forEach(E),this.h()},h(){Me(e,"fill","currentColor"),Me(e,"d",is)},m(t,n){M(t,e,n)},p:Pt,d(t){t&&E(e)}}}function Hs(i){let e,t;return e=new Kt({props:{component:Nt,viewBox:"0 0 24 24",$$slots:{default:[Ns]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment)},l(n){V(e.$$.fragment,n)},m(n,a){N(e,n,a),t=!0},p(n,a){const r={};a&8192&&(r.$$scope={dirty:a,ctx:n}),e.$set(r)},i(n){t||(y(e.$$.fragment,n),t=!0)},o(n){L(e.$$.fragment,n),t=!1},d(n){H(e,n)}}}function js(i){let e,t,n,a,r,l;return e=new kt({props:{$$slots:{default:[Ps]},$$scope:{ctx:i}}}),e.$on("click",i[3]),n=new kt({props:{$$slots:{default:[ws]},$$scope:{ctx:i}}}),n.$on("click",ar),r=new kt({props:{"aria-label":"GitHub",target:"_blank",href:"https://github.com/martynvdijke/SoundBridgeFx",$$slots:{default:[Hs]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment),a=ve(),w(r.$$.fragment)},l(s){V(e.$$.fragment,s),t=Ce(s),V(n.$$.fragment,s),a=Ce(s),V(r.$$.fragment,s)},m(s,o){N(e,s,o),M(s,t,o),N(n,s,o),M(s,a,o),N(r,s,o),l=!0},p(s,o){const c={};o&8192&&(c.$$scope={dirty:o,ctx:s}),e.$set(c);const u={};o&8192&&(u.$$scope={dirty:o,ctx:s}),n.$set(u);const d={};o&8192&&(d.$$scope={dirty:o,ctx:s}),r.$set(d)},i(s){l||(y(e.$$.fragment,s),y(n.$$.fragment,s),y(r.$$.fragment,s),l=!0)},o(s){L(e.$$.fragment,s),L(n.$$.fragment,s),L(r.$$.fragment,s),l=!1},d(s){H(e,s),s&&E(t),H(n,s),s&&E(a),H(r,s)}}}function Gs(i){let e,t,n,a;return e=new sn({props:{$$slots:{default:[ks]},$$scope:{ctx:i}}}),n=new sn({props:{align:"end",toolbar:!0,$$slots:{default:[js]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment)},l(r){V(e.$$.fragment,r),t=Ce(r),V(n.$$.fragment,r)},m(r,l){N(e,r,l),M(r,t,l),N(n,r,l),a=!0},p(r,l){const s={};l&8194&&(s.$$scope={dirty:l,ctx:r}),e.$set(s);const o={};l&8192&&(o.$$scope={dirty:l,ctx:r}),n.$set(o)},i(r){a||(y(e.$$.fragment,r),y(n.$$.fragment,r),a=!0)},o(r){L(e.$$.fragment,r),L(n.$$.fragment,r),a=!1},d(r){H(e,r),r&&E(t),H(n,r)}}}function zs(i){let e,t;return e=new hi({props:{$$slots:{default:[Gs]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment)},l(n){V(e.$$.fragment,n)},m(n,a){N(e,n,a),t=!0},p(n,a){const r={};a&8194&&(r.$$scope={dirty:a,ctx:n}),e.$set(r)},i(n){t||(y(e.$$.fragment,n),t=!0)},o(n){L(e.$$.fragment,n),t=!1},d(n){H(e,n)}}}function Vs(i){let e;return{c(){e=We("home")},l(t){e=Xe(t,"home")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function Ws(i){let e;return{c(){e=We("Home")},l(t){e=Xe(t,"Home")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function Xs(i){let e,t,n,a;return e=new jt({props:{class:"material-icons","aria-hidden":"true",$$slots:{default:[Vs]},$$scope:{ctx:i}}}),n=new Ht({props:{$$slots:{default:[Ws]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment)},l(r){V(e.$$.fragment,r),t=Ce(r),V(n.$$.fragment,r)},m(r,l){N(e,r,l),M(r,t,l),N(n,r,l),a=!0},p(r,l){const s={};l&8192&&(s.$$scope={dirty:l,ctx:r}),e.$set(s);const o={};l&8192&&(o.$$scope={dirty:l,ctx:r}),n.$set(o)},i(r){a||(y(e.$$.fragment,r),y(n.$$.fragment,r),a=!0)},o(r){L(e.$$.fragment,r),L(n.$$.fragment,r),a=!1},d(r){H(e,r),r&&E(t),H(n,r)}}}function Ks(i){let e;return{c(){e=We("wb_incandescent")},l(t){e=Xe(t,"wb_incandescent")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function qs(i){let e;return{c(){e=We("LedFX")},l(t){e=Xe(t,"LedFX")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function Zs(i){let e,t,n,a;return e=new jt({props:{class:"material-icons","aria-hidden":"true",$$slots:{default:[Ks]},$$scope:{ctx:i}}}),n=new Ht({props:{$$slots:{default:[qs]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment)},l(r){V(e.$$.fragment,r),t=Ce(r),V(n.$$.fragment,r)},m(r,l){N(e,r,l),M(r,t,l),N(n,r,l),a=!0},p(r,l){const s={};l&8192&&(s.$$scope={dirty:l,ctx:r}),e.$set(s);const o={};l&8192&&(o.$$scope={dirty:l,ctx:r}),n.$set(o)},i(r){a||(y(e.$$.fragment,r),y(n.$$.fragment,r),a=!0)},o(r){L(e.$$.fragment,r),L(n.$$.fragment,r),a=!1},d(r){H(e,r),r&&E(t),H(n,r)}}}function Js(i){let e;return{c(){e=We("volume_up")},l(t){e=Xe(t,"volume_up")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function Qs(i){let e;return{c(){e=We("Stream")},l(t){e=Xe(t,"Stream")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function Ys(i){let e,t,n,a;return e=new jt({props:{class:"material-icons","aria-hidden":"true",$$slots:{default:[Js]},$$scope:{ctx:i}}}),n=new Ht({props:{$$slots:{default:[Qs]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment)},l(r){V(e.$$.fragment,r),t=Ce(r),V(n.$$.fragment,r)},m(r,l){N(e,r,l),M(r,t,l),N(n,r,l),a=!0},p(r,l){const s={};l&8192&&(s.$$scope={dirty:l,ctx:r}),e.$set(s);const o={};l&8192&&(o.$$scope={dirty:l,ctx:r}),n.$set(o)},i(r){a||(y(e.$$.fragment,r),y(n.$$.fragment,r),a=!0)},o(r){L(e.$$.fragment,r),L(n.$$.fragment,r),a=!1},d(r){H(e,r),r&&E(t),H(n,r)}}}function xs(i){let e;return{c(){e=We("settings")},l(t){e=Xe(t,"settings")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function $s(i){let e;return{c(){e=We("Settings")},l(t){e=Xe(t,"Settings")},m(t,n){M(t,e,n)},d(t){t&&E(e)}}}function er(i){let e,t,n,a;return e=new jt({props:{class:"material-icons","aria-hidden":"true",$$slots:{default:[xs]},$$scope:{ctx:i}}}),n=new Ht({props:{$$slots:{default:[$s]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment)},l(r){V(e.$$.fragment,r),t=Ce(r),V(n.$$.fragment,r)},m(r,l){N(e,r,l),M(r,t,l),N(n,r,l),a=!0},p(r,l){const s={};l&8192&&(s.$$scope={dirty:l,ctx:r}),e.$set(s);const o={};l&8192&&(o.$$scope={dirty:l,ctx:r}),n.$set(o)},i(r){a||(y(e.$$.fragment,r),y(n.$$.fragment,r),a=!0)},o(r){L(e.$$.fragment,r),L(n.$$.fragment,r),a=!1},d(r){H(e,r),r&&E(t),H(n,r)}}}function tr(i){let e,t,n,a,r,l,s,o;return e=new Rt({props:{href:"http://localhost:6207/",activated:i[2]==="Home",$$slots:{default:[Xs]},$$scope:{ctx:i}}}),e.$on("click",i[8]),n=new Rt({props:{href:"/ledfx",activated:i[2]==="LedFx",$$slots:{default:[Zs]},$$scope:{ctx:i}}}),n.$on("click",i[9]),r=new Rt({props:{href:"/stream",activated:i[2]==="Stream",$$slots:{default:[Ys]},$$scope:{ctx:i}}}),r.$on("click",i[10]),s=new Rt({props:{href:"/settings",activated:i[2]==="Settings",$$slots:{default:[er]},$$scope:{ctx:i}}}),s.$on("click",i[11]),{c(){w(e.$$.fragment),t=ve(),w(n.$$.fragment),a=ve(),w(r.$$.fragment),l=ve(),w(s.$$.fragment)},l(c){V(e.$$.fragment,c),t=Ce(c),V(n.$$.fragment,c),a=Ce(c),V(r.$$.fragment,c),l=Ce(c),V(s.$$.fragment,c)},m(c,u){N(e,c,u),M(c,t,u),N(n,c,u),M(c,a,u),N(r,c,u),M(c,l,u),N(s,c,u),o=!0},p(c,u){const d={};u&4&&(d.activated=c[2]==="Home"),u&8192&&(d.$$scope={dirty:u,ctx:c}),e.$set(d);const f={};u&4&&(f.activated=c[2]==="LedFx"),u&8192&&(f.$$scope={dirty:u,ctx:c}),n.$set(f);const h={};u&4&&(h.activated=c[2]==="Stream"),u&8192&&(h.$$scope={dirty:u,ctx:c}),r.$set(h);const g={};u&4&&(g.activated=c[2]==="Settings"),u&8192&&(g.$$scope={dirty:u,ctx:c}),s.$set(g)},i(c){o||(y(e.$$.fragment,c),y(n.$$.fragment,c),y(r.$$.fragment,c),y(s.$$.fragment,c),o=!0)},o(c){L(e.$$.fragment,c),L(n.$$.fragment,c),L(r.$$.fragment,c),L(s.$$.fragment,c),o=!1},d(c){H(e,c),c&&E(t),H(n,c),c&&E(a),H(r,c),c&&E(l),H(s,c)}}}function nr(i){let e,t;return e=new Cs({props:{$$slots:{default:[tr]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment)},l(n){V(e.$$.fragment,n)},m(n,a){N(e,n,a),t=!0},p(n,a){const r={};a&8196&&(r.$$scope={dirty:a,ctx:n}),e.$set(r)},i(n){t||(y(e.$$.fragment,n),t=!0)},o(n){L(e.$$.fragment,n),t=!1},d(n){H(e,n)}}}function ir(i){let e,t;return e=new As({props:{$$slots:{default:[nr]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment)},l(n){V(e.$$.fragment,n)},m(n,a){N(e,n,a),t=!0},p(n,a){const r={};a&8196&&(r.$$scope={dirty:a,ctx:n}),e.$set(r)},i(n){t||(y(e.$$.fragment,n),t=!0)},o(n){L(e.$$.fragment,n),t=!1},d(n){H(e,n)}}}function sr(i){let e,t;const n=i[5].default,a=ue(n,i,i[13],null);return{c(){e=ye("div"),a&&a.c(),this.h()},l(r){e=Le(r,"DIV",{class:!0});var l=ce(e);a&&a.l(l),l.forEach(E),this.h()},h(){Me(e,"class","container")},m(r,l){M(r,e,l),a&&a.m(e,null),t=!0},p(r,l){a&&a.p&&(!t||l&8192)&&de(a,n,r,r[13],t?me(n,r[13],l,null):fe(r[13]),null)},i(r){t||(y(a,r),t=!0)},o(r){L(a,r),t=!1},d(r){r&&E(e),a&&a.d(r)}}}function rr(i){let e,t,n,a,r,l,s,o,c={class:"top-app-bar-container",ariant:"standard",$$slots:{default:[zs]},$$scope:{ctx:i}};e=new xn({props:c}),i[7](e);function u(f){i[12](f)}let d={variant:"modal",$$slots:{default:[ir]},$$scope:{ctx:i}};return i[1]!==void 0&&(d.open=i[1]),a=new Is({props:d}),he.push(()=>wn(a,"open",u)),s=new vi({props:{topAppBar:i[0],$$slots:{default:[sr]},$$scope:{ctx:i}}}),{c(){w(e.$$.fragment),t=ve(),n=ye("div"),w(a.$$.fragment),l=ve(),w(s.$$.fragment),this.h()},l(f){V(e.$$.fragment,f),t=Ce(f),n=Le(f,"DIV",{class:!0});var h=ce(n);V(a.$$.fragment,h),h.forEach(E),l=Ce(f),V(s.$$.fragment,f),this.h()},h(){Me(n,"class","drawer-container svelte-16bycab")},m(f,h){N(e,f,h),M(f,t,h),M(f,n,h),N(a,n,null),M(f,l,h),N(s,f,h),o=!0},p(f,[h]){const g={};h&8194&&(g.$$scope={dirty:h,ctx:f}),e.$set(g);const I={};h&8196&&(I.$$scope={dirty:h,ctx:f}),!r&&h&2&&(r=!0,I.open=f[1],Nn(()=>r=!1)),a.$set(I);const v={};h&1&&(v.topAppBar=f[0]),h&8192&&(v.$$scope={dirty:h,ctx:f}),s.$set(v)},i(f){o||(y(e.$$.fragment,f),y(a.$$.fragment,f),y(s.$$.fragment,f),o=!0)},o(f){L(e.$$.fragment,f),L(a.$$.fragment,f),L(s.$$.fragment,f),o=!1},d(f){i[7](null),H(e,f),f&&E(t),f&&E(n),H(a),f&&E(l),H(s,f)}}}function ar(){}function or(i,e,t){let{$$slots:n={},$$scope:a}=e,r=typeof window>"u"||window.matchMedia("(prefers-color-scheme: light)").matches;function l(){var b;r=!r;let p=document.head.querySelector("#theme");p||(p=document.createElement("link"),p.rel="stylesheet",p.id="theme"),p.href=`/smui${r?"":"-dark"}.css`,(b=document.head.querySelector('link[href$="/smui-dark.css"]'))==null||b.insertAdjacentElement("afterend",p)}let{topAppBar:s}=e,o=!1,c="Home";function u(p){t(2,c=p)}const d=()=>t(1,o=!o);function f(p){he[p?"unshift":"push"](()=>{s=p,t(0,s)})}const h=()=>u("Home"),g=()=>u("LedFx"),I=()=>u("Stream"),v=()=>u("Settings");function C(p){o=p,t(1,o)}return i.$$set=p=>{"topAppBar"in p&&t(0,s=p.topAppBar),"$$scope"in p&&t(13,a=p.$$scope)},[s,o,c,l,u,n,d,f,h,g,I,v,C,a]}class lr extends ae{constructor(e){super(),oe(this,e,or,rr,le,{topAppBar:0})}}function ur(i){let e;const t=i[0].default,n=ue(t,i,i[1],null);return{c(){n&&n.c()},l(a){n&&n.l(a)},m(a,r){n&&n.m(a,r),e=!0},p(a,r){n&&n.p&&(!e||r&2)&&de(n,t,a,a[1],e?me(t,a[1],r,null):fe(a[1]),null)},i(a){e||(y(n,a),e=!0)},o(a){L(n,a),e=!1},d(a){n&&n.d(a)}}}function cr(i){let e,t,n,a;return n=new lr({props:{$$slots:{default:[ur]},$$scope:{ctx:i}}}),{c(){e=ye("meta"),t=ve(),w(n.$$.fragment),this.h()},l(r){const l=Hn("svelte-dlu9t3",document.head);e=Le(l,"META",{name:!0,content:!0}),l.forEach(E),t=Ce(r),V(n.$$.fragment,r),this.h()},h(){document.title="SoundBridgeFX",Me(e,"name","description"),Me(e,"content","SoundBridgeFx")},m(r,l){jn(document.head,e),M(r,t,l),N(n,r,l),a=!0},p(r,[l]){const s={};l&2&&(s.$$scope={dirty:l,ctx:r}),n.$set(s)},i(r){a||(y(n.$$.fragment,r),a=!0)},o(r){L(n.$$.fragment,r),a=!1},d(r){E(e),r&&E(t),H(n,r)}}}function dr(i,e,t){let{$$slots:n={},$$scope:a}=e;return i.$$set=r=>{"$$scope"in r&&t(1,a=r.$$scope)},[n,a]}class Sr extends ae{constructor(e){super(),oe(this,e,dr,cr,le,{})}}export{Sr as default};
